@@ -1,5 +1,5 @@
 /*
- * $Id: shoutcast.c,v 1.141.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: shoutcast.c,v 1.141.2.3 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -93,7 +93,7 @@ typedef struct
   SHOUTcastStream	*stream;
 
   STTransferSession	*session;
-} RefreshInfo;
+} ReloadInfo;
 
 /*** variable declarations ***************************************************/
 
@@ -109,18 +109,18 @@ static regex_t re_page;
 
 /*** function declarations ***************************************************/
 
-static gboolean	refresh_cb	(STCategory	*category,
+static gboolean	reload_cb	(STCategory	*category,
 				 GNode		**categories,
 				 GList		**streams,
 				 gpointer	data,
 				 GError		**err);
 
-static gboolean	refresh_page		(const char	*url,
-					 RefreshInfo	*info,
+static gboolean	reload_page		(const char	*url,
+					 ReloadInfo	*info,
 					 GError		**err);
-static void	refresh_header_cb	(const char	*line,
+static void	reload_header_cb	(const char	*line,
 					 gpointer	data);
-static void	refresh_body_cb		(const char	*line,
+static void	reload_body_cb		(const char	*line,
 					 gpointer	data);
 
 static SHOUTcastStream *stream_new_cb (gpointer data);
@@ -443,7 +443,7 @@ stream_browse_cb (SHOUTcastStream *stream, gpointer data, GError **err)
 {
   if (! stream->homepage) /* older versions of the plugin didn't have this field */
     {
-      g_set_error(err, 0, 0, _("the stream is too old, please refresh"));
+      g_set_error(err, 0, 0, _("the stream is too old, please reload"));
       return FALSE;
     }
 
@@ -451,13 +451,13 @@ stream_browse_cb (SHOUTcastStream *stream, gpointer data, GError **err)
 }
 
 static gboolean
-refresh_cb (STCategory *category,
-	    GNode **categories,
-	    GList **streams,
-	    gpointer data,
-	    GError **err)
+reload_cb (STCategory *category,
+	   GNode **categories,
+	   GList **streams,
+	   gpointer data,
+	   GError **err)
 {
-  RefreshInfo info;
+  ReloadInfo info;
   char *url;
   gboolean status;
 
@@ -475,7 +475,7 @@ refresh_cb (STCategory *category,
 
   url = g_strdup_printf(SHOUTCAST_ROOT "directory/?numresult=%i%s",
 			STREAMS_PER_PAGE, category->url_postfix);
-  status = refresh_page(url, &info, err);
+  status = reload_page(url, &info, err);
   g_free(url);
 
   if (! status)
@@ -496,7 +496,7 @@ refresh_cb (STCategory *category,
 
 	url = g_strdup_printf(SHOUTCAST_ROOT "directory/index.phtml?startat=%i",
 			      info.page * STREAMS_PER_PAGE);
-	status = refresh_page(url, &info, err);
+	status = reload_page(url, &info, err);
 	g_free(url);
 	
 	if (! status)
@@ -510,7 +510,7 @@ refresh_cb (STCategory *category,
 }
 
 static gboolean
-refresh_page (const char *url, RefreshInfo *info, GError **err)
+reload_page (const char *url, ReloadInfo *info, GError **err)
 {
   gboolean status;
   GError *tmp_err = NULL;
@@ -525,9 +525,9 @@ refresh_page (const char *url, RefreshInfo *info, GError **err)
   status = st_transfer_session_get_by_line(info->session,
 					   url,
 					   0,
-					   refresh_header_cb,
+					   reload_header_cb,
 					   info,
-					   refresh_body_cb,
+					   reload_body_cb,
 					   info,
 					   &tmp_err);
 
@@ -555,9 +555,9 @@ refresh_page (const char *url, RefreshInfo *info, GError **err)
 }
 
 static void
-refresh_header_cb (const char *line, gpointer data)
+reload_header_cb (const char *line, gpointer data)
 {
-  RefreshInfo *info = data;
+  ReloadInfo *info = data;
   char *charset;
 
   if (st_re_parse(&re_header_charset, line, &charset))
@@ -568,9 +568,9 @@ refresh_header_cb (const char *line, gpointer data)
 }
 
 static void
-refresh_body_cb (const char *line, gpointer data)
+reload_body_cb (const char *line, gpointer data)
 {
-  RefreshInfo *info = data;
+  ReloadInfo *info = data;
   char *sub1, *sub2, *sub3;
   char *converted = NULL;
   char *expanded;
@@ -834,7 +834,7 @@ init_handler (void)
   st_handler_set_icon_from_inline(handler, sizeof(art_shoutcast), art_shoutcast);
   st_handler_set_stock_categories(handler, stock_categories);
   
-  st_handler_bind(handler, ST_HANDLER_EVENT_REFRESH, refresh_cb, NULL);
+  st_handler_bind(handler, ST_HANDLER_EVENT_RELOAD, reload_cb, NULL);
 
   st_handler_bind(handler, ST_HANDLER_EVENT_STREAM_NEW, stream_new_cb, NULL);
   st_handler_bind(handler, ST_HANDLER_EVENT_STREAM_FIELD_GET, stream_field_get_cb, NULL);
@@ -899,7 +899,7 @@ plugin_init (GError **err)
 {
   gboolean status;
   
-  if (! st_check_api_version(5, 4))
+  if (! st_check_api_version(5, 6))
     {
       g_set_error(err, 0, 0, _("API version mismatch"));
       return FALSE;
