@@ -1,5 +1,5 @@
 /*
- * $Id: sg-util.c,v 1.21.2.2 2004/07/24 16:17:26 jylefort Exp $
+ * $Id: sg-util.c,v 1.21.2.3 2004/08/05 13:37:40 jylefort Exp $
  *
  * Copyright (c) 2003 Jean-Yves Lefort
  * All rights reserved.
@@ -251,3 +251,46 @@ sg_value_array_get_string (GValueArray *value_array)
 
   return g_string_free(string, FALSE);
 }
+
+void
+sg_string_append_escaped (GString *string, const char *str)
+{
+  char *escaped;
+
+  g_return_if_fail(string != NULL);
+  g_return_if_fail(str != NULL);
+
+  escaped = g_markup_escape_text(str, -1);
+
+  g_string_append(string, escaped);
+  g_free(escaped);
+}
+
+void
+sg_string_append_printf_escaped (GString *string, const char *format, ...)
+{
+  va_list args;
+
+  g_return_if_fail(string != NULL);
+  g_return_if_fail(format != NULL);
+
+  va_start(args, format);
+  sg_string_append_vprintf_escaped(string, format, args);
+  va_end(args);
+}
+
+void
+sg_string_append_vprintf_escaped (GString *string,
+				  const char *format,
+				  va_list args)
+{
+  char *escaped;
+
+  g_return_if_fail(string != NULL);
+  g_return_if_fail(format != NULL);
+
+  escaped = g_markup_vprintf_escaped(format, args);
+
+  g_string_append(string, escaped);
+  g_free(escaped);
+}
