@@ -1,5 +1,5 @@
 /*
- * $Id: sg-util.h,v 1.19.2.2 2004/07/24 16:17:26 jylefort Exp $
+ * $Id: sg-util.h,v 1.19.2.3 2004/08/05 13:37:40 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,6 +34,7 @@
 #ifndef _SG_UTIL_H
 #define _SG_UTIL_H
 
+#include <stdarg.h>
 #include <glib-object.h>
 
 #define SG_LIST_FOREACH(var, head)		\
@@ -55,5 +56,13 @@ gboolean	sg_utf8_strcontains		(const char	*big,
 gboolean	sg_utf8_strcasecontains		(const char	*big,
 						 const char	*little);
 char		*sg_value_array_get_string	(GValueArray	*value_array);
+void		sg_string_append_escaped	(GString	*string,
+						 const char	*str);
+void		sg_string_append_printf_escaped	(GString	*string,
+						 const char	*format,
+						 ...);
+void		sg_string_append_vprintf_escaped (GString	*string,
+						  const char	*format,
+						  va_list	args);
 
 #endif /* _SG_UTIL_H */
