@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-auth-dialog.c,v 1.24.2.3 2004/07/24 17:17:55 jylefort Exp $
+ * $Id: sgtk-auth-dialog.c,v 1.24.2.7 2004/08/05 13:37:40 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,10 +32,10 @@
  */
 
 #include "config.h"
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <stdarg.h>
 #include "gettext.h"
+#include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "sgtk-hig.h"
 
@@ -58,9 +58,10 @@ static void sgtk_auth_dialog_class_init	(sGtkAuthDialogClass	*class);
 static void sgtk_auth_dialog_init	(sGtkAuthDialog		*dialog);
 static void sgtk_auth_dialog_finalize	(GObject		*object);
 
-static gboolean	sgtk_auth_dialog_entry_key_press_h  (GtkWidget    *widget,
-						     GdkEventKey  *event,
-						     gpointer     data);
+static void sgtk_auth_dialog_entry_changed_h	(GtkEditable	*editable,
+						 gpointer	user_data);
+static void sgtk_auth_dialog_entry_activate_h	(GtkEntry	*entry,
+						 gpointer	user_data);
      
 /*** implementation **********************************************************/
 
@@ -105,17 +106,17 @@ sgtk_auth_dialog_class_init (sGtkAuthDialogClass *class)
 static void
 sgtk_auth_dialog_init (sGtkAuthDialog *dialog)
 {
-  GtkWidget *ok;
   GtkWidget *table;
   GtkWidget *name_label;
   GtkWidget *password_label;
 
   dialog->priv = g_new0(sGtkAuthDialogPrivate, 1);
 
-  gtk_dialog_add_button(GTK_DIALOG(dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-  ok = gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Authenticate"), GTK_RESPONSE_OK);
-
-  gtk_window_set_default(GTK_WINDOW(dialog), ok);
+  gtk_dialog_add_buttons(GTK_DIALOG(dialog),
+			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			 _("_Authenticate"), GTK_RESPONSE_OK,
+			 NULL);
+  gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
 
   gtk_image_set_from_stock(GTK_IMAGE(SGTK_ALERT_DIALOG(dialog)->image),
 			   GTK_STOCK_DIALOG_AUTHENTICATION,
@@ -142,16 +143,32 @@ sgtk_auth_dialog_init (sGtkAuthDialog *dialog)
   gtk_misc_set_alignment(GTK_MISC(password_label), 0, 0.5);
   gtk_entry_set_visibility(GTK_ENTRY(dialog->priv->password_entry), FALSE);
 
-  g_signal_connect(G_OBJECT(dialog->priv->name_entry), "key-press-event",
-		   G_CALLBACK(sgtk_auth_dialog_entry_key_press_h), dialog);
-  g_signal_connect(G_OBJECT(dialog->priv->password_entry), "key-press-event",
-		   G_CALLBACK(sgtk_auth_dialog_entry_key_press_h), dialog);
+  g_signal_connect(G_OBJECT(dialog->priv->name_entry),
+		   "changed",
+		   G_CALLBACK(sgtk_auth_dialog_entry_changed_h),
+		   dialog);
+  g_signal_connect(G_OBJECT(dialog->priv->password_entry),
+		   "changed",
+		   G_CALLBACK(sgtk_auth_dialog_entry_changed_h),
+		   dialog);
+
+  g_signal_connect(G_OBJECT(dialog->priv->name_entry),
+		   "activate",
+		   G_CALLBACK(sgtk_auth_dialog_entry_activate_h),
+		   dialog->priv->password_entry);
+  g_signal_connect(G_OBJECT(dialog->priv->password_entry),
+		   "activate",
+		   G_CALLBACK(sgtk_auth_dialog_entry_activate_h),
+		   dialog->priv->name_entry);
 
   table = gtk_table_new(3, 2, FALSE);
 
   gtk_table_set_row_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_SPACING);
   gtk_table_set_col_spacings(GTK_TABLE(table), SGTK_HIG_CONTROL_LABEL_SPACING);
   
+  /* spacing between dialog label and controls */
+  gtk_table_set_row_spacing(GTK_TABLE(table), 0, SGTK_HIG_DIALOG_CONTENTS_SPACING);
+
   gtk_table_attach(GTK_TABLE(table), dialog->priv->label, 0, 2, 0, 1,
 		   GTK_FILL,
 		   (GtkAttachOptions) 0,
@@ -195,48 +212,68 @@ sgtk_auth_dialog_finalize (GObject *object)
   G_OBJECT_CLASS(parent_class)->finalize(object);
 }
 
-static gboolean
-sgtk_auth_dialog_entry_key_press_h (GtkWidget *widget,
-				    GdkEventKey *event,
-				    gpointer data)
+static void
+sgtk_auth_dialog_entry_changed_h (GtkEditable *editable, gpointer user_data)
 {
-  if (event->keyval == GDK_Return)
-    {
-      sGtkAuthDialog *dialog = data;
+  sGtkAuthDialog *dialog = user_data;
+  const char *name;
+  const char *password;
 
-      g_return_val_if_fail(SGTK_IS_AUTH_DIALOG(dialog), FALSE);
+  name = gtk_entry_get_text(GTK_ENTRY(dialog->priv->name_entry));
+  password = gtk_entry_get_text(GTK_ENTRY(dialog->priv->password_entry));
 
-      if (widget == dialog->priv->name_entry)
-	gtk_window_set_focus(GTK_WINDOW(dialog), dialog->priv->password_entry);
-      else if (widget == dialog->priv->password_entry)
-	gtk_window_activate_default(GTK_WINDOW(dialog));
-      else
-	g_assert_not_reached();
-    }
+  gtk_dialog_set_response_sensitive(GTK_DIALOG(dialog), GTK_RESPONSE_OK, *name && *password);
+}
 
-  return FALSE;
+static void
+sgtk_auth_dialog_entry_activate_h (GtkEntry *entry, gpointer user_data)
+{
+  GtkWidget *next = user_data;
+  GtkWidget *toplevel;
+
+  toplevel = gtk_widget_get_toplevel(GTK_WIDGET(entry));
+  if (GTK_WIDGET_TOPLEVEL(toplevel)
+      && GTK_WINDOW(toplevel)->default_widget
+      && GTK_WIDGET_IS_SENSITIVE(GTK_WINDOW(toplevel)->default_widget))
+    gtk_window_activate_default(GTK_WINDOW(toplevel));
+  else if (GTK_WIDGET_IS_SENSITIVE(next))
+    gtk_widget_grab_focus(next);
 }
 
 GtkWidget *
-sgtk_auth_dialog_new (GtkWindow *parent, const char *format, ...)
+sgtk_auth_dialog_new (GtkWindow *parent,
+		      const char *primary,
+		      const char *format,
+		      ...)
 {
   sGtkAuthDialog *dialog;
-  va_list args;
-  char *message;
-
-  g_return_val_if_fail(format != NULL, NULL);
+  GString *message;
 
   dialog = g_object_new(SGTK_TYPE_AUTH_DIALOG, NULL);
 
   if (parent)
     gtk_window_set_transient_for(GTK_WINDOW(dialog), parent);
   
-  va_start(args, format);
-  message = g_strdup_vprintf(format, args);
-  va_end(args);
+  message = g_string_new(NULL);
+  if (primary)
+    sg_string_append_printf_escaped(message,
+				    "<span weight=\"bold\" size=\"larger\">%s</span>",
+				    primary);
 
-  gtk_label_set_text(GTK_LABEL(dialog->priv->label), message);
-  g_free(message);
+  if (format)
+    {
+      va_list args;
+
+      if (primary)
+	g_string_append(message, "\n\n");
+
+      va_start(args, format);
+      sg_string_append_vprintf_escaped(message, format, args);
+      va_end(args);
+    }
+  
+  gtk_label_set_markup(GTK_LABEL(dialog->priv->label), message->str);
+  g_string_free(message, TRUE);
 
   return GTK_WIDGET(dialog);
 }
