@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-message-dialog.c,v 1.11 2004/03/08 06:03:30 jylefort Exp $
+ * $Id: sgtk-message-dialog.c,v 1.11.2.2 2004/08/05 13:37:40 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,6 +32,7 @@
  */
 
 #include <gtk/gtk.h>
+#include "sg-util.h"
 #include "sgtk-message-dialog.h"
 #include "sgtk-hig.h"
 
@@ -100,16 +101,16 @@ sgtk_message_dialog_new (GtkWindow *parent,
   message = g_string_new(NULL);
 
   if (primary)
-    g_string_printf(message,
-		    "<span weight=\"bold\" size=\"larger\">%s</span>",
-		    primary);
+    sg_string_append_printf_escaped(message,
+				    "<span weight=\"bold\" size=\"larger\">%s</span>",
+				    primary);
 
   if (secondary)
     {
       if (primary)
 	g_string_append(message, "\n\n");
 
-      g_string_append(message, secondary);
+      sg_string_append_escaped(message, secondary);
     }
 
   gtk_label_set_markup(GTK_LABEL(label), message->str);
