@@ -1,5 +1,5 @@
 /*
- * $Id: st-about-dialog.c,v 1.33.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-about-dialog.c,v 1.33.2.3 2004/08/05 13:42:41 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,6 +34,7 @@
 #include "config.h"
 #include <gtk/gtk.h>
 #include "gettext.h"
+#include "sg-util.h"
 #include "sgtk-dialog.h"
 #include "sgtk-hig.h"
 #include "st-about-dialog.h"
@@ -159,7 +160,7 @@ st_about_dialog_make_info (void)
       SG_LIST_FOREACH(l, st_plugins_list)
 	{
 	  char *filename = l->data;
-	  g_string_append_printf(string, "\n%s", filename);
+	  sg_string_append_printf_escaped(string, "\n%s", filename);
 	}
     }
   else
@@ -172,11 +173,11 @@ st_about_dialog_make_info (void)
       STHandler *handler = l->data;
       const char *copyright;
 
-      g_string_append_printf(string, "\n%s", st_handler_get_label(handler));
+      sg_string_append_printf_escaped(string, "\n%s", st_handler_get_label(handler));
 	  
       copyright = st_handler_get_copyright(handler);
       if (copyright)
-	g_string_append_printf(string, " - %s", copyright);
+	sg_string_append_printf_escaped(string, " - %s", copyright);
     }
       
   return g_string_free(string, FALSE);
