@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab.c,v 1.141.2.3 2004/07/23 15:50:53 jylefort Exp $
+ * $Id: st-browser-tab.c,v 1.141.2.7 2004/08/09 12:43:20 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -52,7 +52,7 @@
 /*** type definitions ********************************************************/
 
 enum {
-  REFRESHING_CHANGED,
+  RELOADING_CHANGED,
   LAST_SIGNAL
 };
 
@@ -68,7 +68,7 @@ typedef struct
   GTimer		*ui_timer;
   gboolean		ui_first;
   STThread		*thread;
-} RefreshThreadInfo;
+} ReloadThreadInfo;
 
 struct _STBrowserTabPrivate
 {
@@ -101,17 +101,17 @@ static void st_browser_tab_finalize	(GObject	*object);
 static void st_browser_tab_unrealize	(GtkWidget	*widget);
 
 static void st_browser_tab_update_counters	(STBrowserTab    *tab);
-static void st_browser_tab_set_refreshing	(STBrowserTab    *tab,
-						 gboolean        refreshing);
+static void st_browser_tab_set_reloading	(STBrowserTab    *tab,
+						 gboolean        reloading);
 
-static void st_browser_tab_finish_refresh	(STBrowserTab    *tab);
+static void st_browser_tab_finish_reload	(STBrowserTab    *tab);
 
-static void st_browser_tab_refresh_thread		(gpointer    data);
-static void st_browser_tab_refresh_thread_print_cb	(const char  *str,
+static void st_browser_tab_reload_thread		(gpointer    data);
+static void st_browser_tab_reload_thread_print_cb	(const char  *str,
 							 gpointer    data);
-static void st_browser_tab_refresh_thread_progress_cb	(double      fraction,
+static void st_browser_tab_reload_thread_progress_cb	(double      fraction,
 							 gpointer    data);
-static void st_browser_tab_refresh_thread_abort_cb	(gpointer    data);
+static void st_browser_tab_reload_thread_abort_cb	(gpointer    data);
 
 static void st_browser_tab_category_selection_changed_h (STCategoryView *view,
 							 gpointer user_data);
@@ -170,16 +170,16 @@ st_browser_tab_class_init (STBrowserTabClass *class)
 						       _("The tab's STHandler object"),
 						       G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 
-  browser_tab_signals[REFRESHING_CHANGED] = g_signal_new("refreshing-changed",
-							 ST_TYPE_BROWSER_TAB,
-							 G_SIGNAL_RUN_LAST,
-							 G_STRUCT_OFFSET(STBrowserTabClass, refreshing_changed),
-							 NULL,
-							 NULL,
-							 g_cclosure_marshal_VOID__BOOLEAN,
-							 G_TYPE_NONE,
-							 1,
-							 G_TYPE_BOOLEAN);
+  browser_tab_signals[RELOADING_CHANGED] = g_signal_new("reloading-changed",
+							ST_TYPE_BROWSER_TAB,
+							G_SIGNAL_RUN_LAST,
+							G_STRUCT_OFFSET(STBrowserTabClass, reloading_changed),
+							NULL,
+							NULL,
+							g_cclosure_marshal_VOID__BOOLEAN,
+							G_TYPE_NONE,
+							1,
+							G_TYPE_BOOLEAN);
 }
 
 static void
@@ -189,7 +189,7 @@ st_browser_tab_init (STBrowserTab *tab)
 
   tab->handler = NULL;
   tab->statusbar = NULL;
-  tab->refreshing = FALSE;
+  tab->reloading = FALSE;
   tab->category_view = NULL;
   tab->stream_view = NULL;
 }
@@ -352,10 +352,10 @@ st_browser_tab_update_sensitivity (STBrowserTab *tab)
 }
 
 void
-st_browser_tab_refresh (STBrowserTab *tab)
+st_browser_tab_reload (STBrowserTab *tab)
 {
   STCategoryBag *category_bag;
-  RefreshThreadInfo *info;
+  ReloadThreadInfo *info;
 
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
@@ -368,7 +368,7 @@ st_browser_tab_refresh (STBrowserTab *tab)
       return;
     }
 
-  info = g_new(RefreshThreadInfo, 1);
+  info = g_new(ReloadThreadInfo, 1);
 
   g_object_ref(tab);
   info->tab = tab;
@@ -376,53 +376,53 @@ st_browser_tab_refresh (STBrowserTab *tab)
   info->ui_timer = g_timer_new();
   info->ui_first = TRUE;
   info->thread = st_thread_new(tab->handler);
-  info->thread->thread_cb = st_browser_tab_refresh_thread;
-  info->thread->print_cb = st_browser_tab_refresh_thread_print_cb;
-  info->thread->progress_cb = st_browser_tab_refresh_thread_progress_cb;
-  info->thread->abort_cb = st_browser_tab_refresh_thread_abort_cb;
+  info->thread->thread_cb = st_browser_tab_reload_thread;
+  info->thread->print_cb = st_browser_tab_reload_thread_print_cb;
+  info->thread->progress_cb = st_browser_tab_reload_thread_progress_cb;
+  info->thread->abort_cb = st_browser_tab_reload_thread_abort_cb;
   info->thread->cb_data = info;
 
-  if (tab->refreshing)
+  if (tab->reloading)
     {
       st_thread_forget(tab->priv->thread);
       gtk_progress_bar_set_fraction(ST_STATUSBAR(tab->statusbar)->progress_bar, 0);
     }
   else
-    st_browser_tab_set_refreshing(tab, TRUE);
+    st_browser_tab_set_reloading(tab, TRUE);
 
   tab->priv->thread = info->thread;
   st_thread_run(tab->priv->thread);
 }
 
 static void
-st_browser_tab_finish_refresh (STBrowserTab *tab)
+st_browser_tab_finish_reload (STBrowserTab *tab)
 {
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
   gtk_statusbar_pop(GTK_STATUSBAR(tab->statusbar), tab->priv->context_thread);
-  st_browser_tab_set_refreshing(tab, FALSE);
+  st_browser_tab_set_reloading(tab, FALSE);
 }
 
 static void
-st_browser_tab_refresh_thread (gpointer data)
+st_browser_tab_reload_thread (gpointer data)
 {
-  RefreshThreadInfo *info = data;
+  ReloadThreadInfo *info = data;
   gboolean status;
   GNode *categories;
   STStreamStore *stream_store;
   GError *err = NULL;
 
-  status = st_handler_refresh(info->tab->handler,
-			      info->category_bag,
-			      &categories,
-			      &stream_store,
-			      &err);
+  status = st_handler_reload(info->tab->handler,
+			     info->category_bag,
+			     &categories,
+			     &stream_store,
+			     &err);
 
   st_thread_validate_callback_return(info->thread, status, err);
   if (! st_thread_is_aborted(info->thread))
     {
       GDK_THREADS_ENTER();
-      st_browser_tab_finish_refresh(info->tab);
+      st_browser_tab_finish_reload(info->tab);
       gdk_flush();
       GDK_THREADS_LEAVE();
     }
@@ -456,7 +456,7 @@ st_browser_tab_refresh_thread (gpointer data)
       char *normalized;
 
       normalized = st_dialog_normalize(err->message);
-      st_error_dialog(_("Unable to refresh."), "%s", normalized);
+      st_error_dialog(_("Unable to reload"), "%s", normalized);
       
       g_free(normalized);
       g_error_free(err);
@@ -473,17 +473,17 @@ st_browser_tab_refresh_thread (gpointer data)
 
 
 static void
-st_browser_tab_refresh_thread_print_cb (const char *str, gpointer data)
+st_browser_tab_reload_thread_print_cb (const char *str, gpointer data)
 {
-  RefreshThreadInfo *info = data;
+  ReloadThreadInfo *info = data;
   
   st_statusbar_print(ST_STATUSBAR(info->tab->statusbar), info->tab->priv->context_thread, str);
 }
 
 static void
-st_browser_tab_refresh_thread_progress_cb (double fraction, gpointer data)
+st_browser_tab_reload_thread_progress_cb (double fraction, gpointer data)
 {
-  RefreshThreadInfo *info = data;
+  ReloadThreadInfo *info = data;
 
   if (fraction == -1)		/* -1 means "pulse" */
     {
@@ -499,11 +499,11 @@ st_browser_tab_refresh_thread_progress_cb (double fraction, gpointer data)
 }
 
 static void
-st_browser_tab_refresh_thread_abort_cb (gpointer data)
+st_browser_tab_reload_thread_abort_cb (gpointer data)
 {
-  RefreshThreadInfo *info = data;
+  ReloadThreadInfo *info = data;
 
-  st_browser_tab_finish_refresh(info->tab);
+  st_browser_tab_finish_reload(info->tab);
 }
 
 gboolean
@@ -511,7 +511,7 @@ st_browser_tab_can_stop (STBrowserTab *tab)
 {
   g_return_val_if_fail(ST_IS_BROWSER_TAB(tab), FALSE);
 
-  return tab->refreshing;
+  return tab->reloading;
 }
 
 void
@@ -524,19 +524,19 @@ st_browser_tab_stop (STBrowserTab *tab)
 }
 
 static void
-st_browser_tab_set_refreshing (STBrowserTab *tab, gboolean refreshing)
+st_browser_tab_set_reloading (STBrowserTab *tab, gboolean reloading)
 {
   GSList *l;
 
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
-  tab->refreshing = refreshing;
+  tab->reloading = reloading;
 
-  st_statusbar_set_active(ST_STATUSBAR(tab->statusbar), tab->refreshing);
+  st_statusbar_set_active(ST_STATUSBAR(tab->statusbar), tab->reloading);
   SG_LIST_FOREACH(l, tab->priv->labels)
-    st_browser_tab_label_set_blinking(ST_BROWSER_TAB_LABEL(l->data), tab->refreshing);
+    st_browser_tab_label_set_blinking(ST_BROWSER_TAB_LABEL(l->data), tab->reloading);
 
-  g_signal_emit(tab, browser_tab_signals[REFRESHING_CHANGED], 0, tab->refreshing);
+  g_signal_emit(tab, browser_tab_signals[RELOADING_CHANGED], 0, tab->reloading);
 }
 
 void
@@ -553,56 +553,53 @@ st_browser_tab_update (STBrowserTab *tab)
   streams = st_handler_get_streams(tab->handler, ST_CATEGORY(category_bag)->name);
   g_object_unref(category_bag);
 
-  if (tab->refreshing)
+  if (tab->reloading)
     st_browser_tab_stop(tab);
 
   st_browser_tab_set_streams(tab, streams);
   if (streams)
     g_object_unref(streams);
 
-  if (ST_HANDLER_EVENT_HAS_REFRESH(tab->handler) && ((! streams) || st_settings.always_refresh))
-    st_browser_tab_refresh(tab);
+  if (ST_HANDLER_EVENT_HAS_RELOAD(tab->handler) && ((! streams) || st_settings.always_reload))
+    st_browser_tab_reload(tab);
 }
 
 static void
 st_browser_tab_update_counters (STBrowserTab *tab)
 {
   GtkTreeModel *model;
+  GString *string;
   int n_streams;
-  char *streams;
-  char *str;
 
   g_return_if_fail(ST_IS_BROWSER_TAB(tab));
 
-  model = gtk_tree_view_get_model(GTK_TREE_VIEW(tab->stream_view));
-  n_streams = model ? st_stream_store_count(ST_STREAM_STORE(model)) : 0;
-  streams = g_strdup_printf(ngettext("%i stream",
-				     "%i streams",
-				     n_streams),
-			    n_streams);
+  string = g_string_new(NULL);
 
   if (tab->category_view)
     {
       int n_categories;
-      char *categories;
 
       model = gtk_tree_view_get_model(GTK_TREE_VIEW(tab->category_view));
-      n_categories = model ? st_category_store_count(ST_CATEGORY_STORE(model)) : 0;
-      categories = g_strdup_printf(ngettext("%i category",
-					    "%i categories",
-					    n_categories),
-				   n_categories);
+      n_categories = model ? sgtk_tree_model_get_count(model) : 0;
 
-      str = g_strdup_printf(_("%s, %s"), categories, streams);
-      g_free(categories);
+      g_string_append_printf(string, ngettext("%i category",
+					      "%i categories",
+					      n_categories),
+			     n_categories);
     }
-  else
-    str = g_strdup(streams);
   
-  st_statusbar_print(ST_STATUSBAR(tab->statusbar), tab->priv->context_counts, str);
+  if (*string->str)
+    g_string_append(string, ", ");
 
-  g_free(streams);
-  g_free(str);
+  model = gtk_tree_view_get_model(GTK_TREE_VIEW(tab->stream_view));
+  n_streams = model ? sgtk_tree_model_get_count(model) : 0;
+  g_string_append_printf(string, ngettext("%i stream",
+					  "%i streams",
+					  n_streams),
+			 n_streams);
+
+  st_statusbar_print(ST_STATUSBAR(tab->statusbar), tab->priv->context_counts, string->str);
+  g_string_free(string, TRUE);
 }
 
 static void
