@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab.h,v 1.41 2004/03/27 21:54:23 jylefort Exp $
+ * $Id: st-browser-tab.h,v 1.41.2.1 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -58,7 +58,7 @@ typedef struct
   STHandler			*handler;
   GtkWidget			*statusbar;
 
-  gboolean			refreshing;
+  gboolean			reloading;
 
   STCategoryView		*category_view;
   STStreamView			*stream_view;
@@ -69,7 +69,7 @@ typedef struct
   GtkHPanedClass		parent_class;
 
   /* signals */
-  void (*refreshing_changed) (STBrowserTab *tab, gboolean refreshing);
+  void (*reloading_changed) (STBrowserTab *tab, gboolean reloading);
 } STBrowserTabClass;
 
 GType		st_browser_tab_get_type		(void);
@@ -81,7 +81,7 @@ void		st_browser_tab_set_label_icon_visible (STBrowserTab *tab,
 
 void		st_browser_tab_update_sensitivity (STBrowserTab	*tab);
 
-void		st_browser_tab_refresh		(STBrowserTab	*tab);
+void		st_browser_tab_reload		(STBrowserTab	*tab);
 void		st_browser_tab_update		(STBrowserTab	*tab);
 gboolean	st_browser_tab_can_stop		(STBrowserTab	*tab);
 void		st_browser_tab_stop		(STBrowserTab	*tab);
