@@ -1,5 +1,5 @@
 /*
- * $Id: st-category-view.h,v 1.24 2004/03/27 21:48:10 jylefort Exp $
+ * $Id: st-category-view.h,v 1.24.2.2 2004/07/23 16:05:16 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -62,7 +62,9 @@ typedef struct
   void (*selection_changed) (STCategoryView *view);
 } STCategoryViewClass;
 
-GType		st_category_view_get_type	(void);
-GtkWidget	*st_category_view_new		(STCategoryStore *store);
+GType		st_category_view_get_type         (void);
+GtkWidget	*st_category_view_new             (STCategoryStore *store);
+void		st_category_view_select_category  (STCategoryView  *view,
+						   STCategoryBag   *bag);
 
 #endif /* _ST_CATEGORY_VIEW_H */
