@@ -1,5 +1,5 @@
 /*
- * $Id: st-config-load.c,v 1.35.2.4 2004/07/24 16:53:40 jylefort Exp $
+ * $Id: st-config-load.c,v 1.35.2.5 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -79,7 +79,8 @@ enum {
   STATEMENT_OPTIONS_GALEON_THEMES_SYSTEM_DIR,	/* obsolete */
   STATEMENT_OPTIONS_GALEON_THEMES_USER_DIR,	/* obsolete */
   STATEMENT_OPTIONS_SELECTED_HANDLER,
-  STATEMENT_OPTIONS_ALWAYS_REFRESH,
+  STATEMENT_OPTIONS_ALWAYS_REFRESH,		/* deprecated */
+  STATEMENT_OPTIONS_ALWAYS_RELOAD,
   STATEMENT_OPTIONS_FIND_TOKEN,
   STATEMENT_OPTIONS_FIND_CASE_SENSITIVE,
   STATEMENT_OPTIONS_FIND_WRAP_AROUND,
@@ -250,10 +251,14 @@ static SGParserDefinition config_definitions[] = {
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_SELECTED_HANDLER,
     "selected_handler",	FALSE,		G_TYPE_STRING
   }, 
-  {
+  {				/* deprecated */
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_ALWAYS_REFRESH,
     "always_refresh",	FALSE,		G_TYPE_BOOLEAN
   }, 
+  {
+    STATEMENT_OPTIONS,	STATEMENT_OPTIONS_ALWAYS_RELOAD,
+    "always_reload",	FALSE,		G_TYPE_BOOLEAN
+  }, 
   {
     STATEMENT_OPTIONS,	STATEMENT_OPTIONS_FIND_TOKEN,
     "find_token",	FALSE,		G_TYPE_STRING
@@ -522,8 +527,9 @@ st_config_load (const char *filename, GError **err)
 	      st_settings.selected_handler_name = g_value_dup_string(&info.statement->value);
 	      break;
 
-	    case STATEMENT_OPTIONS_ALWAYS_REFRESH:
-	      st_settings.always_refresh = g_value_get_boolean(&info.statement->value);
+	    case STATEMENT_OPTIONS_ALWAYS_REFRESH: /* deprecated */
+	    case STATEMENT_OPTIONS_ALWAYS_RELOAD:
+	      st_settings.always_reload = g_value_get_boolean(&info.statement->value);
 	      break;
 
 	    case STATEMENT_OPTIONS_FIND_TOKEN:
