@@ -1,5 +1,5 @@
 /*
- * $Id: st-handler.c,v 1.124.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-handler.c,v 1.124.2.3 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -115,16 +115,16 @@ static gboolean    st_handler_set_stock_categories_cb	(GNode       *node,
 static gboolean    st_handler_get_stock_category_cb	(GNode       *node,
 							 gpointer    data);
 
-static void        st_handler_refresh_multiple_cb	(gpointer    key,
+static void        st_handler_reload_multiple_cb	(gpointer    key,
 							 gpointer    value,
 							 gpointer    user_data);
 
-static gboolean    st_handler_refresh_single		(STHandler	*handler,
+static gboolean    st_handler_reload_single		(STHandler	*handler,
 							 STCategoryBag	*category_bag,
 							 GNode		**category_bags,
 							 GSList		**stream_bags,
 							 GError		**err);
-static gboolean    st_handler_refresh_multiple		(STHandler	*handler,
+static gboolean    st_handler_reload_multiple		(STHandler	*handler,
 							 GNode		**category_bags,
 							 GHashTable	**stream_bag_lists,
 							 GError		**err);
@@ -503,11 +503,11 @@ st_handler_validate (STHandler *handler, GError **err)
 }
 
 gboolean
-st_handler_refresh (STHandler *handler,
-		    STCategoryBag *category_bag,
-		    GNode **categories,
-		    STStreamStore **stream_store,
-		    GError **err)
+st_handler_reload (STHandler *handler,
+		   STCategoryBag *category_bag,
+		   GNode **categories,
+		   STStreamStore **stream_store,
+		   GError **err)
 {
   gboolean status;
 
@@ -516,17 +516,17 @@ st_handler_refresh (STHandler *handler,
   g_return_val_if_fail(categories != NULL, FALSE);
   g_return_val_if_fail(stream_store != NULL, FALSE);
 
-  if (st_handler_event_is_bound(handler, ST_HANDLER_EVENT_REFRESH_MULTIPLE))
+  if (st_handler_event_is_bound(handler, ST_HANDLER_EVENT_RELOAD_MULTIPLE))
     {
       GHashTable *stream_lists;
 
-      status = st_handler_refresh_multiple(handler,
-					   categories,
-					   &stream_lists,
-					   err);
+      status = st_handler_reload_multiple(handler,
+					  categories,
+					  &stream_lists,
+					  err);
       if (status)
 	{
-	  g_hash_table_foreach(stream_lists, st_handler_refresh_multiple_cb, handler);
+	  g_hash_table_foreach(stream_lists, st_handler_reload_multiple_cb, handler);
 	  g_hash_table_destroy(stream_lists);
 
 	  *stream_store = st_handler_get_streams(handler, ST_CATEGORY(category_bag)->name);
@@ -536,11 +536,11 @@ st_handler_refresh (STHandler *handler,
     {
       GSList *streams;
       
-      status = st_handler_refresh_single(handler,
-					 category_bag,
-					 categories,
-					 &streams,
-					 err);
+      status = st_handler_reload_single(handler,
+					category_bag,
+					categories,
+					&streams,
+					err);
       if (status)
 	{
 	  *stream_store = st_stream_store_new(handler);
@@ -555,9 +555,9 @@ st_handler_refresh (STHandler *handler,
 }
 
 static void
-st_handler_refresh_multiple_cb (gpointer key,
-				gpointer value,
-				gpointer user_data)
+st_handler_reload_multiple_cb (gpointer key,
+			       gpointer value,
+			       gpointer user_data)
 {
   const char *category_name = key;
   GSList *streams = value;
@@ -572,11 +572,11 @@ st_handler_refresh_multiple_cb (gpointer key,
 }
 
 static gboolean
-st_handler_refresh_single (STHandler *handler,
-			   STCategoryBag *category_bag,
-			   GNode **category_bags,
-			   GSList **stream_bags,
-			   GError **err)
+st_handler_reload_single (STHandler *handler,
+			  STCategoryBag *category_bag,
+			  GNode **category_bags,
+			  GSList **stream_bags,
+			  GError **err)
 {
   gboolean status;
   GNode *categories = NULL;
@@ -587,11 +587,11 @@ st_handler_refresh_single (STHandler *handler,
   g_return_val_if_fail(category_bags != NULL, FALSE);
   g_return_val_if_fail(stream_bags != NULL, FALSE);
 
-  status = st_handler_event_refresh(handler,
-				    ST_CATEGORY(category_bag),
-				    &categories,
-				    &streams,
-				    err);
+  status = st_handler_event_reload(handler,
+				   ST_CATEGORY(category_bag),
+				   &categories,
+				   &streams,
+				   err);
   
   if (status)
     {
@@ -611,10 +611,10 @@ st_handler_refresh_single (STHandler *handler,
 }
 
 static gboolean
-st_handler_refresh_multiple (STHandler *handler,
-			     GNode **category_bags,
-			     GHashTable **stream_bag_lists,
-			     GError **err)
+st_handler_reload_multiple (STHandler *handler,
+			    GNode **category_bags,
+			    GHashTable **stream_bag_lists,
+			    GError **err)
 {
   gboolean status;
   GNode *categories = NULL;
@@ -624,10 +624,10 @@ st_handler_refresh_multiple (STHandler *handler,
   g_return_val_if_fail(category_bags != NULL, FALSE);
   g_return_val_if_fail(stream_bag_lists != NULL, FALSE);
 
-  status = st_handler_event_refresh_multiple(handler,
-					     &categories,
-					     &stream_lists,
-					     err);
+  status = st_handler_event_reload_multiple(handler,
+					    &categories,
+					    &stream_lists,
+					    err);
 
   if (status)
     {
@@ -1136,27 +1136,27 @@ st_handler_get_fields_sort_order (STHandler *handler)
 /*** events ******************************************************************/
 
 gboolean
-st_handler_event_refresh (STHandler *handler,
-			  STCategory *category,
-			  GNode **categories,
-			  GList **streams,
-			  GError **err)
+st_handler_event_reload (STHandler *handler,
+			 STCategory *category,
+			 GNode **categories,
+			 GList **streams,
+			 GError **err)
 {
-  STHandlerCallback *callback = &handler->priv->callbacks[ST_HANDLER_EVENT_REFRESH];
-  STHandlerRefreshCallback *cb = callback->cb;
+  STHandlerCallback *callback = &handler->priv->callbacks[ST_HANDLER_EVENT_RELOAD];
+  STHandlerReloadCallback *cb = callback->cb;
 
   g_return_val_if_fail(cb != NULL, FALSE);
   return cb(category, categories, streams, callback->data, err);
 }
 
 gboolean
-st_handler_event_refresh_multiple (STHandler *handler,
-				   GNode **categories,
-				   GHashTable **streams,
-				   GError **err)
+st_handler_event_reload_multiple (STHandler *handler,
+				  GNode **categories,
+				  GHashTable **streams,
+				  GError **err)
 {
-  STHandlerCallback *callback = &handler->priv->callbacks[ST_HANDLER_EVENT_REFRESH_MULTIPLE];
-  STHandlerRefreshMultipleCallback *cb = callback->cb;
+  STHandlerCallback *callback = &handler->priv->callbacks[ST_HANDLER_EVENT_RELOAD_MULTIPLE];
+  STHandlerReloadMultipleCallback *cb = callback->cb;
 
   g_return_val_if_fail(cb != NULL, FALSE);
   return cb(categories, streams, callback->data, err);
