@@ -1,5 +1,5 @@
 /*
- * $Id: st-handler.h,v 1.62 2004/03/27 21:25:03 jylefort Exp $
+ * $Id: st-handler.h,v 1.62.2.1 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -46,9 +46,9 @@
 #define ST_HANDLER_MUST_CONFIRM_DELETION(handler) \
   ((st_handler_get_flags((handler)) & ST_HANDLER_CONFIRM_DELETION) != 0)
 
-#define ST_HANDLER_EVENT_HAS_REFRESH(handler) 				\
-  (st_handler_event_is_bound((handler), ST_HANDLER_EVENT_REFRESH) 	\
-   || st_handler_event_is_bound((handler), ST_HANDLER_EVENT_REFRESH_MULTIPLE))
+#define ST_HANDLER_EVENT_HAS_RELOAD(handler) 				\
+  (st_handler_event_is_bound((handler), ST_HANDLER_EVENT_RELOAD) 	\
+   || st_handler_event_is_bound((handler), ST_HANDLER_EVENT_RELOAD_MULTIPLE))
 #define ST_HANDLER_EVENT_HAS_TUNE_IN(handler) 					\
   (st_handler_event_is_bound((handler), ST_HANDLER_EVENT_STREAM_TUNE_IN) 	\
    || st_handler_event_is_bound((handler), ST_HANDLER_EVENT_STREAM_TUNE_IN_MULTIPLE))
@@ -57,7 +57,7 @@ void		st_handler_complete		(STHandler	*handler);
 gboolean	st_handler_validate		(STHandler	*handler,
 						 GError		**err);
 
-gboolean	st_handler_refresh		(STHandler	*handler,
+gboolean	st_handler_reload		(STHandler	*handler,
 						 STCategoryBag	*category_bag,
 						 GNode		**categories,
 						 STStreamStore	**stream_store,
@@ -110,12 +110,12 @@ STCategoryBag	*st_handler_get_selected_category	(STHandler     *handler);
 
 /* events */
 
-gboolean	st_handler_event_refresh           (STHandler	*handler,
+gboolean	st_handler_event_reload            (STHandler	*handler,
 						    STCategory	*category,
 						    GNode	**categories,
 						    GList	**streams,
 						    GError	**err);
-gboolean	st_handler_event_refresh_multiple  (STHandler	*handler,
+gboolean	st_handler_event_reload_multiple   (STHandler	*handler,
 						    GNode	**categories,
 						    GHashTable	**streams,
 						    GError	**err);
