@@ -1,5 +1,5 @@
 /*
- * $Id: st-handlers.c,v 1.20.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-handlers.c,v 1.20.2.3 2004/08/05 12:46:36 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -60,13 +60,13 @@ st_handlers_add (STHandler *handler)
   else
     {
       if (st_plugin_current)
-	st_error_dialog(_("A plugin error has occurred."),
+	st_error_dialog(_("A plugin error has occurred"),
 			_("In <i>%s</i>, handler <i>%s</i> is malformed and cannot be registered (%s).\n"
 			  "\n"
 			  "You should report this problem to the plugin maintainer."),
 			st_plugin_current, st_handler_get_name(handler), err->message);
       else
-	st_error_dialog(_("A handler error has occurred."),
+	st_error_dialog(_("A handler error has occurred"),
 			_("Handler <i>%s</i> is malformed and cannot be registered (%s).\n"
 			  "\n"
 			  "You should report this problem to the streamtuner maintainer."),
