@@ -1,5 +1,5 @@
 /*
- * $Id: st-link.c,v 1.11.2.2 2004/05/11 15:40:41 jylefort Exp $
+ * $Id: st-link.c,v 1.11.2.4 2004/08/05 13:48:27 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -328,7 +328,7 @@ st_link_open (STLink *link)
       
       normalized = st_dialog_normalize(err->message);
       
-      st_error_dialog(_("Unable to visit the link."), "%s", normalized);
+      st_error_dialog(_("Unable to visit the link"), "%s", normalized);
       
       g_free(normalized);
       g_error_free(err);
@@ -353,6 +353,9 @@ st_link_new (void)
   return g_object_new(ST_TYPE_LINK, NULL);
 }
 
+/*
+ * Set the label of the link. TEXT can contain Pango markup.
+ */
 void
 st_link_set_text (STLink *link, const char *text)
 {
