@@ -1,5 +1,5 @@
 /*
- * $Id: st-main.c,v 1.10.2.3 2004/07/25 17:47:24 jylefort Exp $
+ * $Id: st-main.c,v 1.10.2.4 2004/08/05 13:01:50 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -208,10 +208,27 @@ st_main_quit (void)
       save = response == GTK_RESPONSE_YES;
     }
   
-  g_object_unref(shell);
+  /*
+   * HIG 2.0:
+   *
+   * "When a confirmation alert is needed, present it immediately. If
+   * the user confirms closing without saving, hide the alert and the
+   * document or application window immediately, before doing any
+   * necessary internal clean-up. If the user chooses to save before
+   * closing, hide the alert immediately but show the document window
+   * until the document is saved, in case an error occurs. Then hide
+   * the document window immediately after it has been saved
+   * successfuly."
+   */
+
+  st_shell_prepare_finalize(shell);
+
   if (save)
     st_session_save();
-  
+
+  st_shell_hide(shell);
+  g_object_unref(shell);
+
   gtk_main_quit();
 }
 
