@@ -1,5 +1,5 @@
 /*
- * $Id: st-plugins.c,v 1.14.2.3 2004/07/25 18:42:04 jylefort Exp $
+ * $Id: st-plugins.c,v 1.14.2.4 2004/08/05 12:46:36 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -61,7 +61,7 @@ st_plugins_load (void)
   
   if (! g_module_supported())
     {
-      st_error_dialog(_("Unable to load plugins."),
+      st_error_dialog(_("Unable to load plugins"),
 		      _("Modules are not supported on this platform."));
       return;
     }
@@ -121,7 +121,7 @@ st_plugins_scan (const char *dirname, GError **err)
 					  pathname, load_err->message);
 	      normalized = st_dialog_normalize(secondary);
 
-	      st_error_dialog(_("A plugin error has occurred."), "%s", normalized);
+	      st_error_dialog(_("A plugin error has occurred"), "%s", normalized);
 	      
 	      g_free(secondary);
 	      g_free(normalized);
@@ -158,7 +158,7 @@ st_plugins_scan_or_warn (const char *dirname)
 				  dirname, err->message);
       normalized = st_dialog_normalize(secondary);
       
-      st_error_dialog(_("A plugin error has occurred."), "%s", normalized);
+      st_error_dialog(_("A plugin error has occurred"), "%s", normalized);
 
       g_free(secondary);
       g_free(normalized);
