@@ -1,5 +1,5 @@
 /*
- * $Id: st-preselections.c,v 1.6.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-preselections.c,v 1.6.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -33,8 +33,8 @@
 
 #include "config.h"
 #include <glib.h>
-#include <glib/gi18n-lib.h>
 #include "art/preselections.h"
+#include "gettext.h"
 #include "sg-util.h"
 #include "st-action.h"
 #include "st-handler.h"
