@@ -1,5 +1,5 @@
 /*
- * $Id: st-session.c,v 1.18.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-session.c,v 1.18.2.3 2004/08/05 12:46:36 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -72,7 +72,7 @@ st_session_load (void)
 
 	  normalized = st_dialog_normalize(err->message);
 
-	  st_error_dialog(_("Unable to load configuration."), "%s", normalized);
+	  st_error_dialog(_("Unable to load configuration"), "%s", normalized);
 
 	  g_free(normalized);
 	  g_clear_error(&err);
@@ -87,7 +87,7 @@ st_session_load (void)
 
 	  normalized = st_dialog_normalize(err->message);
 	  
-	  st_error_dialog(_("Unable to load cache."), "%s", normalized);
+	  st_error_dialog(_("Unable to load cache"), "%s", normalized);
 
 	  g_free(normalized);
 	  g_clear_error(&err);
@@ -121,7 +121,7 @@ st_session_save (void)
       
       normalized = st_dialog_normalize(err->message);
       
-      st_error_dialog(_("Unable to save configuration."), "%s", normalized);
+      st_error_dialog(_("Unable to save configuration"), "%s", normalized);
       
       g_free(normalized);
       g_clear_error(&err);
@@ -135,7 +135,7 @@ st_session_save (void)
       
       normalized = st_dialog_normalize(err->message);
       
-      st_error_dialog(_("Unable to save cache."), "%s", normalized);
+      st_error_dialog(_("Unable to save cache"), "%s", normalized);
       
       g_free(normalized);
       g_clear_error(&err);
@@ -149,7 +149,7 @@ st_session_save (void)
       
       normalized = st_dialog_normalize(err->message);
       
-      st_error_dialog(_("Unable to save splash screen setting."), "%s", normalized);
+      st_error_dialog(_("Unable to save splash screen setting"), "%s", normalized);
       
       g_free(normalized);
       g_clear_error(&err);
@@ -173,7 +173,7 @@ st_session_mkdir (const char *dirname)
 	  normalized = st_dialog_normalize(secondary);
 	  g_free(secondary);
 
-	  st_error_dialog(_("Unable to save session."), "%s", normalized);
+	  st_error_dialog(_("Unable to save session"), "%s", normalized);
 	  g_free(normalized);
 
 	  status = FALSE;
