@@ -1,5 +1,5 @@
 /*
- * $Id: st-settings.c,v 1.27.2.4 2004/07/25 18:42:04 jylefort Exp $
+ * $Id: st-settings.c,v 1.27.2.7 2004/08/06 00:36:30 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -62,7 +62,7 @@ st_settings_init (const char *custom_private_dir)
   
   if (! (home = g_get_home_dir()))
     {
-      st_error_dialog(_("A fatal error has occurred."),
+      st_error_dialog(_("A fatal error has occurred"),
 		      _("Could not find your home directory."));
       exit(1);
     }
@@ -114,9 +114,9 @@ st_settings_init (const char *custom_private_dir)
 
   st_settings.selected_handler_name = NULL;
   
-  st_settings.always_refresh = FALSE;
+  st_settings.always_reload = FALSE;
 
-  st_settings.find_token = g_strdup("");
+  st_settings.find_token = NULL;
   st_settings.find_history = NULL;
   st_settings.find_case_sensitive = FALSE;
   st_settings.find_wrap_around = FALSE;
