@@ -1,5 +1,5 @@
 /*
- * $Id: st-shell.c,v 1.170.2.12 2004/07/26 15:28:41 jylefort Exp $
+ * $Id: st-shell.c,v 1.170.2.44 2004/08/09 13:14:03 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -33,7 +33,6 @@
 
 #include "config.h"
 #include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 #include "art/streamtuner.h"
 #include "gettext.h"
 #include "sg-util.h"
@@ -73,6 +72,7 @@ struct _STShellPrivate
 
   /* menubar */
   GtkItemFactory	*factory;
+  GtkWidget		*menubar;
   STStreamMenuItems	*stream_items;
   GtkWidget		*select_all_item;
   GtkWidget		*find_item;
@@ -80,10 +80,14 @@ struct _STShellPrivate
   GtkWidget		*find_previous_item;
   GtkWidget		*search_in_all_categories_item;
   GtkWidget		*stop_item;
-  GtkWidget		*refresh_item;
+  GtkWidget		*reload_item;
   GtkWidget		*view_tab_icons_item;
   GtkWidget		*stream_columns_item;
   GtkWidget		*directories_menu;
+  GtkWidget		*previous_directory_item;
+  GtkWidget		*next_directory_item;
+  GtkWidget		*move_directory_left_item;
+  GtkWidget		*move_directory_right_item;
   GtkWidget		*directory_homepage_item;
   GSList		*directory_items;
 
@@ -93,7 +97,7 @@ struct _STShellPrivate
   GtkWidget		*record_button;
   GtkWidget		*browse_button;
   GtkWidget		*stop_button;
-  GtkWidget		*refresh_button;
+  GtkWidget		*reload_button;
   GtkWidget		*link;
 
   /* notebook */
@@ -115,6 +119,14 @@ struct _STShellPrivate
   GtkWidget		*find;
   GtkWidget		*preferences;
   GtkWidget		*about;
+
+  /* fullscreen mode */
+  gboolean		fullscreen;
+  GtkWidget		*leave_fullscreen_popup;
+  gboolean		leave_fullscreen_popup_visible;
+  unsigned int		leave_fullscreen_timeout_id;
+  unsigned int		screen_size_changed_hid;
+  unsigned int		key_press_event_hid;
 };
 
 /*** variable declarations ***************************************************/
@@ -153,9 +165,30 @@ static void st_shell_menubar_toolbar_size_toggled_h (GtkCheckMenuItem *item,
 
 static void st_shell_menubar_directory_toggled_h (GtkCheckMenuItem *item,
 						  gpointer user_data);
+static gboolean st_shell_window_state_event_h (GtkWidget *widget,
+					       GdkEventWindowState *event,
+					       gpointer user_data);
 static gboolean st_shell_window_delete_event_h (GtkWidget *widget,
 						GdkEvent *event,
 						gpointer user_data);
+
+static void st_shell_fullscreen (STShell *shell);
+static void st_shell_unfullscreen (STShell *shell);
+static void st_shell_leave_fullscreen_button_clicked_h (GtkButton *button,
+							gpointer user_data);
+static gboolean st_shell_leave_fullscreen_timeout_cb (gpointer data);
+static gboolean st_shell_leave_fullscreen_enter_notify_event_h (GtkWidget *widget,
+								GdkEventCrossing *event,
+								gpointer user_data);
+static gboolean st_shell_leave_fullscreen_leave_notify_event_h (GtkWidget *widget,
+								GdkEventCrossing *event,
+								gpointer user_data);
+static void st_shell_update_leave_fullscreen_popup_position (STShell *shell);
+static void st_shell_screen_size_changed_h (GdkScreen *screen, gpointer user_data);
+static gboolean st_shell_window_key_press_event_h (GtkWidget *widget,
+						   GdkEventKey *event,
+						   gpointer user_data);
+
 static void st_shell_toolbar_button_clicked_h (GtkButton *button,
 					       gpointer user_data);
 
@@ -180,6 +213,7 @@ static void st_shell_switch_page_h (GtkNotebook *notebook,
 				    unsigned int page_num,
 				    gpointer user_data);
 static void st_shell_tab_selected (STShell *shell);
+static void st_shell_tab_moved (STShell *shell);
 
 static void st_shell_update_visibility (STShell *shell);
 static void st_shell_update_toolbar_style (STShell *shell);
@@ -190,8 +224,8 @@ static STBrowserTab *st_shell_get_selected_tab (STShell *shell);
 static gboolean st_shell_can_stop (STShell *shell);
 static void st_shell_stop (STShell *shell);
 
-static gboolean st_shell_can_refresh (STShell *shell);
-static void st_shell_refresh (STShell *shell);
+static gboolean st_shell_can_reload (STShell *shell);
+static void st_shell_reload (STShell *shell);
 
 static gboolean st_shell_can_select_all (STShell *shell);
 static void st_shell_select_all (STShell *shell);
@@ -234,9 +268,21 @@ static void st_shell_visit_directory_homepage (STShell *shell);
 
 static void st_shell_stream_properties_update_stream (STShell *shell);
 
+static gboolean st_shell_can_select_previous_tab (STShell *shell);
 static void st_shell_select_previous_tab (STShell *shell);
+
+static gboolean st_shell_can_select_next_tab (STShell *shell);
 static void st_shell_select_next_tab (STShell *shell);
 
+static gboolean st_shell_can_move_tab (STShell *shell, int direction);
+static void st_shell_move_tab (STShell *shell, int direction);
+
+static gboolean st_shell_can_move_tab_left (STShell *shell);
+static void st_shell_move_tab_left (STShell *shell);
+
+static gboolean st_shell_can_move_tab_right (STShell *shell);
+static void st_shell_move_tab_right (STShell *shell);
+
 static void st_shell_visit_homepage (STShell *shell, const char *url);
 
 static void st_shell_help (STShell *shell);
@@ -258,9 +304,9 @@ static void st_shell_stream_activated_h (GtkTreeView *treeview,
 					 GtkTreePath *arg1,
 					 GtkTreeViewColumn *arg2,
 					 gpointer user_data);
-static void st_shell_tab_refreshing_changed_h (STBrowserTab *tab,
-					       gboolean refreshing,
-					       gpointer user_data);
+static void st_shell_tab_reloading_changed_h (STBrowserTab *tab,
+					      gboolean reloading,
+					      gpointer user_data);
 
 /*** implementation **********************************************************/
 
@@ -319,14 +365,20 @@ st_shell_init (STShell *shell)
   st_shell_update_toolbar_style(shell);
   st_shell_update_toolbar_size(shell);
 
-  /* select a tab */
+  /* select a tab and focus its stream view */
 
   if (st_settings.selected_handler_name)
     handler = st_handlers_find_by_name(st_settings.selected_handler_name);
-  if (! handler)
+  if (! handler && st_handlers_list)
     handler = st_handlers_list->data; /* fallback */
   if (handler)
-    st_shell_select_tab(shell, st_shell_get_tab_with_handler(shell, handler), TRUE);
+    {
+      STBrowserTab *tab;
+      
+      tab = st_shell_get_tab_with_handler(shell, handler);
+      st_shell_select_tab(shell, tab, TRUE);
+      gtk_widget_grab_focus(GTK_WIDGET(tab->stream_view));
+    }
 
   /* initialize the sensitivity */
 
@@ -337,26 +389,9 @@ static void
 st_shell_finalize (GObject *object)
 {
   STShell *shell = ST_SHELL(object);
-  STBrowserTab *selected_tab;
 
-  /* stop everything */
+  /* destroy the window */
   
-  if (st_shell_can_stop(shell))
-    st_shell_stop(shell);
-
-  /* store some settings and destroy the window */
-  
-  selected_tab = st_shell_get_selected_tab(shell);
-  if (selected_tab)
-    {
-      g_free(st_settings.selected_handler_name);
-      st_settings.selected_handler_name = g_strdup(st_handler_get_name(selected_tab->handler));
-    }
-  
-  gtk_window_get_size(GTK_WINDOW(shell->priv->window),
-		      &st_settings.main_window_width,
-		      &st_settings.main_window_height);
-
   gtk_widget_destroy(shell->priv->window);
 
   /* cleanup */
@@ -396,12 +431,34 @@ st_shell_make_window (STShell *shell)
 			      st_settings.main_window_width,
 			      st_settings.main_window_height);
 
+  g_signal_connect(G_OBJECT(shell->priv->window),
+		   "window-state-event",
+		   G_CALLBACK(st_shell_window_state_event_h),
+		   shell);
   g_signal_connect(G_OBJECT(shell->priv->window),
 		   "delete-event",
 		   G_CALLBACK(st_shell_window_delete_event_h),
 		   NULL);
 }
 
+static gboolean
+st_shell_window_state_event_h (GtkWidget *widget,
+			       GdkEventWindowState *event,
+			       gpointer user_data)
+{
+  STShell *shell = user_data;
+
+  if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
+    {
+      if (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN)
+	st_shell_fullscreen(shell);
+      else
+	st_shell_unfullscreen(shell);
+    }
+
+  return FALSE;			/* propagate event */
+}
+
 static gboolean
 st_shell_window_delete_event_h (GtkWidget *widget,
 				GdkEvent *event,
@@ -412,6 +469,193 @@ st_shell_window_delete_event_h (GtkWidget *widget,
   return TRUE;
 }
 
+static void
+st_shell_fullscreen (STShell *shell)
+{
+  GtkWidget *button;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  shell->priv->fullscreen = TRUE;
+  shell->priv->leave_fullscreen_popup = gtk_window_new(GTK_WINDOW_POPUP);
+  
+  button = gtk_button_new_from_stock(ST_STOCK_LEAVE_FULLSCREEN);
+  gtk_container_add(GTK_CONTAINER(shell->priv->leave_fullscreen_popup), button);
+  gtk_widget_show(button);
+
+  g_signal_connect(G_OBJECT(button),
+		   "clicked",
+		   G_CALLBACK(st_shell_leave_fullscreen_button_clicked_h),
+		   shell);
+
+  st_shell_update_visibility(shell);
+  st_shell_update_toolbar_style(shell);
+
+  shell->priv->leave_fullscreen_popup_visible = TRUE;
+  st_shell_update_leave_fullscreen_popup_position(shell);
+  gtk_widget_show(shell->priv->leave_fullscreen_popup);
+
+  shell->priv->screen_size_changed_hid
+    = g_signal_connect(G_OBJECT(gdk_screen_get_default()),
+		       "size-changed",
+		       G_CALLBACK(st_shell_screen_size_changed_h),
+		       shell);
+  shell->priv->key_press_event_hid
+    = g_signal_connect(G_OBJECT(shell->priv->window),
+		       "key-press-event",
+		       G_CALLBACK(st_shell_window_key_press_event_h),
+		       shell);
+
+  g_signal_connect(G_OBJECT(shell->priv->leave_fullscreen_popup),
+		   "enter-notify-event",
+		   G_CALLBACK(st_shell_leave_fullscreen_enter_notify_event_h),
+		   shell);
+  g_signal_connect(G_OBJECT(shell->priv->leave_fullscreen_popup),
+		   "leave-notify-event",
+		   G_CALLBACK(st_shell_leave_fullscreen_leave_notify_event_h),
+		   shell);
+
+  shell->priv->leave_fullscreen_timeout_id = g_timeout_add(5000, st_shell_leave_fullscreen_timeout_cb, shell);
+}
+
+static void
+st_shell_unfullscreen (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  g_signal_handler_disconnect(gdk_screen_get_default(), shell->priv->screen_size_changed_hid);
+  g_signal_handler_disconnect(shell->priv->window, shell->priv->key_press_event_hid);
+
+  if (shell->priv->leave_fullscreen_timeout_id)
+    {
+      g_source_remove(shell->priv->leave_fullscreen_timeout_id);
+      shell->priv->leave_fullscreen_timeout_id = 0;
+    }
+
+  gtk_widget_destroy(shell->priv->leave_fullscreen_popup);
+  shell->priv->leave_fullscreen_popup = NULL;
+  shell->priv->fullscreen = FALSE;
+
+  st_shell_update_visibility(shell);
+  st_shell_update_toolbar_style(shell);
+}
+
+static void
+st_shell_leave_fullscreen_button_clicked_h (GtkButton *button,
+					    gpointer user_data)
+{
+  STShell *shell = user_data;
+
+  gtk_window_unfullscreen(GTK_WINDOW(shell->priv->window));
+}
+
+static gboolean
+st_shell_leave_fullscreen_timeout_cb (gpointer data)
+{
+  STShell *shell = data;
+
+  GDK_THREADS_ENTER();
+
+  shell->priv->leave_fullscreen_popup_visible = FALSE;
+  st_shell_update_leave_fullscreen_popup_position(shell);
+  shell->priv->leave_fullscreen_timeout_id = 0;
+
+  GDK_THREADS_LEAVE();
+  
+  return FALSE;			/* remove timeout */
+}
+
+static gboolean
+st_shell_leave_fullscreen_enter_notify_event_h (GtkWidget *widget,
+						GdkEventCrossing *event,
+						gpointer user_data)
+{
+  STShell *shell = user_data;
+
+  if (shell->priv->leave_fullscreen_timeout_id)
+    {
+      g_source_remove(shell->priv->leave_fullscreen_timeout_id);
+      shell->priv->leave_fullscreen_timeout_id = 0;
+    }
+
+  shell->priv->leave_fullscreen_popup_visible = TRUE;
+  st_shell_update_leave_fullscreen_popup_position(shell);
+
+  return FALSE;			/* propagate event */
+}
+
+static gboolean
+st_shell_leave_fullscreen_leave_notify_event_h (GtkWidget *widget,
+						GdkEventCrossing *event,
+						gpointer user_data)
+{
+  STShell *shell = user_data;
+
+  if (shell->priv->leave_fullscreen_timeout_id)
+    {
+      g_source_remove(shell->priv->leave_fullscreen_timeout_id);
+      shell->priv->leave_fullscreen_timeout_id = 0;
+    }
+
+  shell->priv->leave_fullscreen_timeout_id = g_timeout_add(5000, st_shell_leave_fullscreen_timeout_cb, shell);
+
+  return FALSE;			/* propagate event */
+}
+
+static void
+st_shell_update_leave_fullscreen_popup_position (STShell *shell)
+{
+  GdkScreen *screen;
+  int monitor_num;
+  GdkRectangle screen_rect;
+  int popup_width;
+  int popup_height;
+  int y;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(shell->priv->leave_fullscreen_popup != NULL);
+
+  screen = gdk_screen_get_default();
+  monitor_num = gdk_screen_get_monitor_at_window(screen, shell->priv->window->window);
+  gdk_screen_get_monitor_geometry(screen, monitor_num, &screen_rect);
+  gtk_window_get_size(GTK_WINDOW(shell->priv->leave_fullscreen_popup), &popup_width, &popup_height);
+
+  y = screen_rect.y;
+  if (! shell->priv->leave_fullscreen_popup_visible)
+    y -= popup_height - 2;
+
+  gtk_window_move(GTK_WINDOW(shell->priv->leave_fullscreen_popup), screen_rect.width - popup_width, y);
+}
+
+static void
+st_shell_screen_size_changed_h (GdkScreen *screen, gpointer user_data)
+{
+  STShell *shell = user_data;
+
+  st_shell_update_leave_fullscreen_popup_position(shell);
+}
+
+static gboolean
+st_shell_window_key_press_event_h (GtkWidget *widget,
+				   GdkEventKey *event,
+				   gpointer user_data)
+{
+  STShell *shell = user_data;
+  static unsigned int escape_key = 0;
+  static GdkModifierType escape_mods;
+
+  if (! escape_key)
+    gtk_accelerator_parse("Escape", &escape_key, &escape_mods);
+
+  if (event->keyval == escape_key && (escape_mods & event->state) == escape_mods)
+    {
+      gtk_window_unfullscreen(GTK_WINDOW(shell->priv->window));
+      return TRUE;	/* Escape is the shortcut for "Stop", block it */
+    }
+  else
+    return FALSE;	/* propagate event */
+}
+
 static void
 st_shell_make_menubar (STShell *shell)
 {
@@ -421,11 +665,21 @@ st_shell_make_menubar (STShell *shell)
       NULL,					0,
       "<Branch>",				NULL
     },
+    {
+      N_("/Stream/_New Preselection"),		"<Control>N",
+      st_shell_new_preselection,		0,
+      "<StockItem>",				ST_STOCK_NEW_PRESELECTION
+    },
     {
       "/Stream/separator1",			NULL,
       NULL,					0,
       "<Separator>",				NULL
     },
+    {
+      "/Stream/separator2",			NULL,
+      NULL,					0,
+      "<Separator>",				NULL
+    },
     {
       N_("/Stream/_Quit"),			NULL,
       st_main_quit,				0,
@@ -439,7 +693,7 @@ st_shell_make_menubar (STShell *shell)
     {
       N_("/Edit/Select _All"),			"<Control>A",
       st_shell_select_all,			0,
-      "<Item>",					NULL
+      "<StockItem>",				ST_STOCK_SELECT_ALL
     },
     {
       "/Edit/separator1",			NULL,
@@ -592,9 +846,9 @@ st_shell_make_menubar (STShell *shell)
       "<StockItem>",				GTK_STOCK_STOP
     },
     {
-      N_("/View/_Refresh"),			"<Control>R",
-      st_shell_refresh,				0,
-      "<StockItem>",				GTK_STOCK_REFRESH
+      N_("/View/_Reload"),			"<Control>R",
+      st_shell_reload,				0,
+      "<StockItem>",				ST_STOCK_RELOAD
     },
     {
       N_("/_Directories"),			NULL,
@@ -602,14 +856,9 @@ st_shell_make_menubar (STShell *shell)
       "<Branch>",				NULL
     },
     {
-      N_("/Directories/_Previous"),		NULL,
-      st_shell_select_previous_tab,		0,
-      "<StockItem>",				GTK_STOCK_GO_BACK
-    },
-    {
-      N_("/Directories/_Next"),			NULL,
-      st_shell_select_next_tab,			0,
-      "<StockItem>",				GTK_STOCK_GO_FORWARD
+      N_("/Directories/_Visit Directory Homepage"), NULL,
+      st_shell_visit_directory_homepage,	0,
+      "<StockItem>",				GTK_STOCK_HOME
     },
     {
       "/Directories/separator1",		NULL,
@@ -617,9 +866,29 @@ st_shell_make_menubar (STShell *shell)
       "<Separator>",				NULL
     },
     {
-      N_("/Directories/_Homepage of Selected Directory"), NULL,
-      st_shell_visit_directory_homepage,	0,
-      "<StockItem>",				GTK_STOCK_HOME
+      N_("/Directories/_Previous Directory"),	"<Control>Page_Up",
+      st_shell_select_previous_tab,		0,
+      "<StockItem>",				GTK_STOCK_GO_BACK
+    },
+    {
+      N_("/Directories/_Next Directory"),	"<Control>Page_Down",
+      st_shell_select_next_tab,			0,
+      "<StockItem>",				GTK_STOCK_GO_FORWARD
+    },
+    {
+      "/Directories/separator2",		NULL,
+      NULL,					0,
+      "<Separator>",				NULL
+    },
+    {
+      N_("/Directories/Move Directory _Left"),	"<Shift><Control>Page_Up",
+      st_shell_move_tab_left,			0,
+      "<Item>",					NULL
+    },
+    {
+      N_("/Directories/Move Directory _Right"),	"<Shift><Control>Page_Down",
+      st_shell_move_tab_right,			0,
+      "<Item>",					NULL
     },
     {
       N_("/_Help"),				NULL,
@@ -670,29 +939,38 @@ st_shell_make_menubar (STShell *shell)
   menu = gtk_item_factory_get_widget(shell->priv->factory, N_("/Stream"));
 
   shell->priv->stream_items = st_stream_menu_items_new(shell, shell->priv->accel_group);
-  st_stream_menu_items_prepend_to_shell(shell->priv->stream_items, GTK_MENU_SHELL(menu));
+  st_stream_menu_items_insert_into_shell(shell->priv->stream_items, GTK_MENU_SHELL(menu), 2);
 
   accel_path = g_strdup_printf("<streamtuner-Browser>/Stream/%s", _("Tune in"));
-  gtk_accel_map_add_entry(accel_path, GDK_T, GDK_CONTROL_MASK);
+  sgtk_accel_map_add_entry(accel_path, "<Control>T");
   g_free(accel_path);
 
   accel_path = g_strdup_printf("<streamtuner-Browser>/Stream/%s", _("Delete"));
-  gtk_accel_map_add_entry(accel_path, GDK_Delete, 0);
+  sgtk_accel_map_add_entry(accel_path, "Delete");
+  g_free(accel_path);
+
+  accel_path = g_strdup_printf("<streamtuner-Browser>/Stream/%s", _("Properties"));
+  sgtk_accel_map_add_entry(accel_path, "<Alt>Return");
   g_free(accel_path);
 
   /* remember the items we'll need later on */
 
+  shell->priv->menubar = gtk_item_factory_get_widget(shell->priv->factory, "<streamtuner-Browser>");
   shell->priv->select_all_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Select All"));
   shell->priv->find_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find"));
   shell->priv->find_next_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find Next"));
   shell->priv->find_previous_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Find Previous"));
   shell->priv->search_in_all_categories_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Edit/Search in All Categories"));
   shell->priv->stop_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Stop"));
-  shell->priv->refresh_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Refresh"));
+  shell->priv->reload_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Reload"));
   shell->priv->view_tab_icons_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Tab Icons"));
   shell->priv->stream_columns_item = gtk_item_factory_get_item(shell->priv->factory, N_("/View/Stream Columns"));
   shell->priv->directories_menu = gtk_item_factory_get_widget(shell->priv->factory, N_("/Directories"));
-  shell->priv->directory_homepage_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Directories/Homepage of Selected Directory"));
+  shell->priv->previous_directory_item = gtk_item_factory_get_widget(shell->priv->factory, N_("/Directories/Previous Directory"));
+  shell->priv->next_directory_item = gtk_item_factory_get_widget(shell->priv->factory, N_("/Directories/Next Directory"));
+  shell->priv->move_directory_left_item = gtk_item_factory_get_widget(shell->priv->factory, N_("/Directories/Move Directory Left"));
+  shell->priv->move_directory_right_item = gtk_item_factory_get_widget(shell->priv->factory, N_("/Directories/Move Directory Right"));
+  shell->priv->directory_homepage_item = gtk_item_factory_get_item(shell->priv->factory, N_("/Directories/Visit Directory Homepage"));
 
   /* add directory items */
 
@@ -717,9 +995,8 @@ st_shell_make_menubar (STShell *shell)
 
   /* pack the menubar */
   
-  menu = gtk_item_factory_get_widget(shell->priv->factory, "<streamtuner-Browser>");
-  gtk_box_pack_start(GTK_BOX(shell->priv->box), menu, FALSE, FALSE, 0);
-  gtk_widget_show(menu);
+  gtk_box_pack_start(GTK_BOX(shell->priv->box), shell->priv->menubar, FALSE, FALSE, 0);
+  gtk_widget_show(shell->priv->menubar);
 }
 
 static void
@@ -728,6 +1005,7 @@ st_shell_menubar_make_directory_items (STShell *shell)
   GtkWidget *separator;
   GSList *group = NULL;
   GSList *l;
+  unsigned int num = 0;
 
   g_return_if_fail(ST_IS_SHELL(shell));
 
@@ -746,15 +1024,28 @@ st_shell_menubar_make_directory_items (STShell *shell)
   SG_LIST_FOREACH(l, st_handlers_list)
     {
       STHandler *handler = l->data;
+      const char *label = st_handler_get_label(handler);
       GtkWidget *item;
       unsigned int hid;
 
-      item = gtk_radio_menu_item_new_with_label(group, st_handler_get_label(handler));
+      item = gtk_radio_menu_item_new_with_label(group, label);
       group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(item));
 
       gtk_widget_show(item);
       gtk_menu_shell_append(GTK_MENU_SHELL(shell->priv->directories_menu), item);
 
+      if (++num < 10)
+	{
+	  char *accel_path;
+	  char *accelerator;
+
+	  accel_path = g_strdup_printf("<streamtuner-Browser>/Directories/%s", label);
+	  accelerator = g_strdup_printf("<Control>%i", num);
+	  sgtk_accel_map_change_entry(accel_path, accelerator, TRUE);
+	  g_free(accel_path);
+	  g_free(accelerator);
+	}
+
       hid = g_signal_connect(G_OBJECT(item),
 			     "toggled",
 			     G_CALLBACK(st_shell_menubar_directory_toggled_h),
@@ -949,13 +1240,13 @@ st_shell_make_toolbar (STShell *shell)
 						      (GtkSignalFunc) st_shell_toolbar_button_clicked_h,
 						      shell,
 						      -1);
-  shell->priv->refresh_button = gtk_toolbar_insert_stock(GTK_TOOLBAR(shell->priv->toolbar),
-							 GTK_STOCK_REFRESH,
-							 _("Refresh the selected category"),
-							 NULL,
-							 (GtkSignalFunc) st_shell_toolbar_button_clicked_h,
-							 shell,
-							 -1);
+  shell->priv->reload_button = gtk_toolbar_insert_stock(GTK_TOOLBAR(shell->priv->toolbar),
+							ST_STOCK_RELOAD,
+							_("Reload the selected category"),
+							NULL,
+							(GtkSignalFunc) st_shell_toolbar_button_clicked_h,
+							shell,
+							-1);
 
   gtk_toolbar_append_space(GTK_TOOLBAR(shell->priv->toolbar));
 
@@ -982,8 +1273,8 @@ st_shell_toolbar_button_clicked_h (GtkButton *button, gpointer user_data)
     st_shell_browse(shell);
   else if ((GtkWidget *) button == shell->priv->stop_button)
     st_shell_stop(shell);
-  else if ((GtkWidget *) button == shell->priv->refresh_button)
-    st_shell_refresh(shell);
+  else if ((GtkWidget *) button == shell->priv->reload_button)
+    st_shell_reload(shell);
   else
     g_return_if_reached();
 }
@@ -1049,8 +1340,8 @@ st_shell_make_notebook (STShell *shell)
 		       shell);
 			
       g_signal_connect(G_OBJECT(tab),
-		       "refreshing-changed",
-		       G_CALLBACK(st_shell_tab_refreshing_changed_h),
+		       "reloading-changed",
+		       G_CALLBACK(st_shell_tab_reloading_changed_h),
 		       shell);
 
       if (ST_BROWSER_TAB(tab)->category_view)
@@ -1115,14 +1406,8 @@ st_shell_tab_label_drag_end_h (GtkWidget *widget,
 {
   STShell *shell = user_data;
 
-  /* a tab might have been moved, reorder the handlers list */
-  st_handlers_list = g_slist_sort_with_data(st_handlers_list,
-					    st_shell_handlers_compare,
-					    shell);
-
-  /* reorder the directories menu by recreating it */
-  st_shell_menubar_make_directory_items(shell);
-  st_shell_menubar_select_directory_item(shell);
+  /* a tab might have been moved */
+  st_shell_tab_moved(shell);
 }
 
 static int
@@ -1190,7 +1475,7 @@ st_shell_tab_selected (STShell *shell)
   /* update toolbar */
 
   description = st_handler_get_description(tab->handler);
-  markup = g_strdup_printf("<span size=\"x-large\">%s</span>", description ? description : st_handler_get_label(tab->handler));
+  markup = g_markup_printf_escaped("<span size=\"x-large\">%s</span>", description ? description : st_handler_get_label(tab->handler));
   st_link_set_text(ST_LINK(shell->priv->link), markup);
   g_free(markup);
 
@@ -1210,7 +1495,7 @@ st_shell_tab_selected (STShell *shell)
   /* work-around a bug in the Bluecurve theme engine */
   gtk_widget_realize(GTK_WIDGET(ST_STATUSBAR(tab->statusbar)->progress_bar));
 
-  if (! gtk_tree_view_get_model(GTK_TREE_VIEW(tab->stream_view)) && ! tab->refreshing)
+  if (! gtk_tree_view_get_model(GTK_TREE_VIEW(tab->stream_view)) && ! tab->reloading)
     st_browser_tab_update(tab);
   
   st_shell_update_sensitivity(shell);
@@ -1224,6 +1509,23 @@ st_shell_tab_selected (STShell *shell)
     }
 }
 
+static void
+st_shell_tab_moved (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  /* reorder the handlers list */
+  st_handlers_list = g_slist_sort_with_data(st_handlers_list,
+					    st_shell_handlers_compare,
+					    shell);
+
+  /* reorder the directories menu by recreating it */
+  st_shell_menubar_make_directory_items(shell);
+  st_shell_menubar_select_directory_item(shell);
+
+  st_shell_update_sensitivity(shell);
+}
+
 static void
 st_shell_make_statusbox (STShell *shell)
 {
@@ -1238,11 +1540,19 @@ st_shell_update_visibility (STShell *shell)
 {
   GSList *l;
 
+  /*
+   * FIXME: fullscreen mode: HIG 2.0 says:
+   *
+   * "However, make its menus and items accessible from the keyboard
+   * as usual."
+   */
+
+  g_object_set(shell->priv->menubar, "visible", ! shell->priv->fullscreen, NULL);
   g_object_set(shell->priv->toolbar, "visible", st_settings.view_toolbar, NULL);
   gtk_notebook_set_show_tabs(GTK_NOTEBOOK(shell->priv->notebook), st_settings.view_tabs);
   SG_LIST_FOREACH(l, shell->priv->tabs)
     st_browser_tab_set_label_icon_visible(l->data, st_settings.view_tab_icons);
-  g_object_set(shell->priv->statusbox, "visible", st_settings.view_statusbar, NULL);
+  g_object_set(shell->priv->statusbox, "visible", st_settings.view_statusbar && ! shell->priv->fullscreen, NULL);
 }
 
 static void
@@ -1258,6 +1568,9 @@ st_shell_update_toolbar_style (STShell *shell)
       g_object_get(settings, "gtk-toolbar-style", &style, NULL);
     }
 
+  if (shell->priv->fullscreen && style == GTK_TOOLBAR_BOTH)
+    style = GTK_TOOLBAR_ICONS;
+    
   gtk_toolbar_set_style(GTK_TOOLBAR(shell->priv->toolbar), style);
 }
 
@@ -1291,6 +1604,40 @@ st_shell_show (STShell *shell)
   gtk_widget_show(shell->priv->window);
 }
 
+void
+st_shell_hide (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  gtk_widget_hide(shell->priv->window);
+}
+
+void
+st_shell_prepare_finalize (STShell *shell)
+{
+  STBrowserTab *selected_tab;
+
+  g_return_if_fail(ST_IS_SHELL(shell));
+
+  /* stop everything */
+  
+  if (st_shell_can_stop(shell))
+    st_shell_stop(shell);
+
+  /* store some settings */
+  
+  selected_tab = st_shell_get_selected_tab(shell);
+  if (selected_tab)
+    {
+      g_free(st_settings.selected_handler_name);
+      st_settings.selected_handler_name = g_strdup(st_handler_get_name(selected_tab->handler));
+    }
+  
+  gtk_window_get_size(GTK_WINDOW(shell->priv->window),
+		      &st_settings.main_window_width,
+		      &st_settings.main_window_height);
+}
+
 void
 st_shell_update_title (STShell *shell)
 {
@@ -1337,7 +1684,11 @@ st_shell_update_sensitivity (STShell *shell)
   gtk_widget_set_sensitive(shell->priv->find_previous_item, st_shell_can_find_previous(shell));
   gtk_widget_set_sensitive(shell->priv->search_in_all_categories_item, st_shell_can_search_in_all_categories(shell));
   gtk_widget_set_sensitive(shell->priv->stop_item, st_shell_can_stop(shell));
-  gtk_widget_set_sensitive(shell->priv->refresh_item, st_shell_can_refresh(shell));
+  gtk_widget_set_sensitive(shell->priv->reload_item, st_shell_can_reload(shell));
+  gtk_widget_set_sensitive(shell->priv->previous_directory_item, st_shell_can_select_previous_tab(shell));
+  gtk_widget_set_sensitive(shell->priv->next_directory_item, st_shell_can_select_next_tab(shell));
+  gtk_widget_set_sensitive(shell->priv->move_directory_left_item, st_shell_can_move_tab_left(shell));
+  gtk_widget_set_sensitive(shell->priv->move_directory_right_item, st_shell_can_move_tab_right(shell));
   gtk_widget_set_sensitive(shell->priv->directory_homepage_item, st_shell_can_visit_directory_homepage(shell));
 
   /* toolbar */
@@ -1345,7 +1696,7 @@ st_shell_update_sensitivity (STShell *shell)
   gtk_widget_set_sensitive(shell->priv->record_button, st_shell_can_record(shell));
   gtk_widget_set_sensitive(shell->priv->browse_button, st_shell_can_browse(shell));
   gtk_widget_set_sensitive(shell->priv->stop_button, st_shell_can_stop(shell));
-  gtk_widget_set_sensitive(shell->priv->refresh_button, st_shell_can_refresh(shell));
+  gtk_widget_set_sensitive(shell->priv->reload_button, st_shell_can_reload(shell));
 
   /* tabs */
   SG_LIST_FOREACH(l, shell->priv->tabs)
@@ -1402,7 +1753,7 @@ st_shell_stop (STShell *shell)
 }
 
 static gboolean
-st_shell_can_refresh (STShell *shell)
+st_shell_can_reload (STShell *shell)
 {
   STBrowserTab *selected_tab;
 
@@ -1411,19 +1762,19 @@ st_shell_can_refresh (STShell *shell)
   selected_tab = st_shell_get_selected_tab(shell);
 
   return selected_tab
-    && ST_HANDLER_EVENT_HAS_REFRESH(selected_tab->handler);
+    && ST_HANDLER_EVENT_HAS_RELOAD(selected_tab->handler);
 }
 
 static void
-st_shell_refresh (STShell *shell)
+st_shell_reload (STShell *shell)
 {
   STBrowserTab *selected_tab;
 
   g_return_if_fail(ST_IS_SHELL(shell));
-  g_return_if_fail(st_shell_can_refresh(shell));
+  g_return_if_fail(st_shell_can_reload(shell));
 
   selected_tab = st_shell_get_selected_tab(shell);
-  st_browser_tab_refresh(selected_tab);
+  st_browser_tab_reload(selected_tab);
 }
 
 static gboolean
@@ -1476,12 +1827,12 @@ st_shell_find (STShell *shell)
       shell->priv->find = sgtk_find_dialog_new(GTK_WINDOW(shell->priv->window));
       g_object_add_weak_pointer(G_OBJECT(shell->priv->find), (gpointer *) &shell->priv->find);
 
-      sgtk_find_dialog_set_token(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_token);
+      sgtk_find_dialog_set_token(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_token ? st_settings.find_token : "");
       sgtk_find_dialog_set_history(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_history);
       sgtk_find_dialog_set_case_sensitive(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_case_sensitive);
       sgtk_find_dialog_set_wrap_around(SGTK_FIND_DIALOG(shell->priv->find), st_settings.find_wrap_around);
 
-      navigation_sensitive = *st_settings.find_token != 0;
+      navigation_sensitive = st_settings.find_token && *st_settings.find_token;
       sgtk_find_dialog_set_previous_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
       sgtk_find_dialog_set_next_sensitive(SGTK_FIND_DIALOG(shell->priv->find), navigation_sensitive);
       
@@ -1508,12 +1859,15 @@ st_shell_find_notify_h (GObject *object,
 
   if (! strcmp(name, "token"))
     {
+      const char *token;
       gboolean navigation_sensitive;
 
-      g_free(st_settings.find_token);
-      st_settings.find_token = g_strdup(sgtk_find_dialog_get_token(dialog));
+      token = sgtk_find_dialog_get_token(dialog);
 
-      navigation_sensitive = *st_settings.find_token != 0;
+      g_free(st_settings.find_token);
+      st_settings.find_token = *token ? g_strdup(token) : NULL;
+
+      navigation_sensitive = st_settings.find_token && *st_settings.find_token;
       sgtk_find_dialog_set_previous_sensitive(dialog, navigation_sensitive);
       sgtk_find_dialog_set_next_sensitive(dialog, navigation_sensitive);
     }
@@ -1559,6 +1913,7 @@ st_shell_find_response_h (GtkDialog *dialog,
 {
   STShell *shell = data;
   sGtkDirection direction;
+  const char *token;
 
   switch (response)
     {
@@ -1579,8 +1934,10 @@ st_shell_find_response_h (GtkDialog *dialog,
       g_return_if_reached();
     }
 
+  token = sgtk_find_dialog_get_token(SGTK_FIND_DIALOG(dialog));
+
   g_free(shell->priv->find_token);
-  shell->priv->find_token = g_strdup(sgtk_find_dialog_get_token(SGTK_FIND_DIALOG(dialog)));
+  shell->priv->find_token = *token ? g_strdup(token) : NULL;
   shell->priv->find_case_sensitive = sgtk_find_dialog_get_case_sensitive(SGTK_FIND_DIALOG(dialog));
   st_shell_find_real(shell, direction, sgtk_find_dialog_get_wrap_around(SGTK_FIND_DIALOG(dialog)));
 }
@@ -1693,7 +2050,7 @@ st_shell_search_in_all_categories (STShell *shell)
 
   st_category_bag_select(search_category);
   st_category_view_select_category(selected_tab->category_view, search_category);
-  st_browser_tab_refresh(selected_tab);
+  st_browser_tab_reload(selected_tab);
 }
 
 static void
@@ -2000,7 +2357,7 @@ st_shell_delete_streams (STShell *shell)
 	    normalized = st_dialog_normalize(err->message);
 	    g_error_free(err);
 	    
-	    st_error_dialog(_("Unable to delete stream."), "%s", normalized);
+	    st_error_dialog(_("Unable to delete stream"), "%s", normalized);
 	    g_free(normalized);
 	  }
       }
@@ -2098,35 +2455,107 @@ st_shell_select_tab (STShell *shell,
     gtk_notebook_set_page(GTK_NOTEBOOK(shell->priv->notebook), num);
 }
 
+static gboolean
+st_shell_can_select_previous_tab (STShell *shell)
+{
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  return gtk_notebook_get_current_page(GTK_NOTEBOOK(shell->priv->notebook)) > 0;
+}
+
 static void
 st_shell_select_previous_tab (STShell *shell)
 {
-  int num;
-
   g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_select_previous_tab(shell));
+
+  gtk_notebook_prev_page(GTK_NOTEBOOK(shell->priv->notebook));
+}
+
+static gboolean
+st_shell_can_select_next_tab (STShell *shell)
+{
+  int num;
+  int npages;
+
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
 
   num = gtk_notebook_get_current_page(GTK_NOTEBOOK(shell->priv->notebook));
-  if (--num < 0)
-    num = gtk_notebook_get_n_pages(GTK_NOTEBOOK(shell->priv->notebook)) - 1;
+  npages = gtk_notebook_get_n_pages(GTK_NOTEBOOK(shell->priv->notebook));
 
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(shell->priv->notebook), num);
+  return num < npages - 1;
 }
 
 static void
 st_shell_select_next_tab (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_select_next_tab(shell));
+
+  gtk_notebook_next_page(GTK_NOTEBOOK(shell->priv->notebook));
+}
+
+static gboolean
+st_shell_can_move_tab (STShell *shell, int direction)
 {
   int num;
   int npages;
 
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  num = gtk_notebook_get_current_page(GTK_NOTEBOOK(shell->priv->notebook)) + direction;
+  npages = gtk_notebook_get_n_pages(GTK_NOTEBOOK(shell->priv->notebook));
+
+  return npages > 1 && num >= 0 && num < npages;
+}
+
+static void
+st_shell_move_tab (STShell *shell, int direction)
+{
+  int num;
+  GtkWidget *child;
+
   g_return_if_fail(ST_IS_SHELL(shell));
 
   num = gtk_notebook_get_current_page(GTK_NOTEBOOK(shell->priv->notebook));
-  npages = gtk_notebook_get_n_pages(GTK_NOTEBOOK(shell->priv->notebook));
+  child = gtk_notebook_get_nth_page(GTK_NOTEBOOK(shell->priv->notebook), num);
+  gtk_notebook_reorder_child(GTK_NOTEBOOK(shell->priv->notebook), child, num + direction);
 
-  if (++num == npages)
-    num = 0;
+  st_shell_tab_moved(shell);
+}
 
-  gtk_notebook_set_current_page(GTK_NOTEBOOK(shell->priv->notebook), num);
+static gboolean
+st_shell_can_move_tab_left (STShell *shell)
+{
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  return st_shell_can_move_tab(shell, -1);
+}
+
+static void
+st_shell_move_tab_left (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_move_tab_left(shell));
+
+  st_shell_move_tab(shell, -1);
+}
+
+static gboolean
+st_shell_can_move_tab_right (STShell *shell)
+{
+  g_return_val_if_fail(ST_IS_SHELL(shell), FALSE);
+
+  return st_shell_can_move_tab(shell, +1);
+}
+
+static void
+st_shell_move_tab_right (STShell *shell)
+{
+  g_return_if_fail(ST_IS_SHELL(shell));
+  g_return_if_fail(st_shell_can_move_tab_right(shell));
+
+  st_shell_move_tab(shell, +1);
 }
 
 static void
@@ -2143,7 +2572,7 @@ st_shell_visit_homepage (STShell *shell, const char *url)
 
       normalized = st_dialog_normalize(err->message);
 
-      st_error_dialog(_("Unable to visit the homepage."), "%s", normalized);
+      st_error_dialog(_("Unable to visit the homepage"), "%s", normalized);
 
       g_free(normalized);
       g_error_free(err);
@@ -2272,13 +2701,13 @@ st_shell_stream_activated_h (GtkTreeView *treeview,
 }
 
 static void
-st_shell_tab_refreshing_changed_h (STBrowserTab *tab,
-				   gboolean refreshing,
-				   gpointer user_data)
+st_shell_tab_reloading_changed_h (STBrowserTab *tab,
+				  gboolean reloading,
+				  gpointer user_data)
 {
   STShell *shell = user_data;
 
-  if (refreshing)
+  if (reloading)
     /*
      * The selected_category label might have been changed by url_cb,
      * so we update the shell title.
