@@ -1,5 +1,5 @@
 /*
- * $Id: st-shell.h,v 1.37 2004/03/27 11:44:40 jylefort Exp $
+ * $Id: st-shell.h,v 1.37.2.1 2004/08/05 13:01:50 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -65,7 +65,11 @@ typedef struct
 GType		st_shell_get_type			(void);
 
 STShell		*st_shell_new				(void);
+
 void		st_shell_show				(STShell   *shell);
+void		st_shell_hide				(STShell   *shell);
+
+void		st_shell_prepare_finalize		(STShell   *shell);
 
 void		st_shell_update_title			(STShell   *shell);
 void		st_shell_update_sensitivity		(STShell   *shell);
