@@ -1,5 +1,5 @@
 /*
- * $Id: st-stock.c,v 1.35.2.3 2004/07/25 17:47:24 jylefort Exp $
+ * $Id: st-stock.c,v 1.35.2.8 2004/08/06 18:53:54 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,7 +34,6 @@
 #include "config.h"
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include "art/add_bookmark.h"
 #include "art/tune_in.h"
 #include "art/record.h"
 #include "art/browse.h"
@@ -51,11 +50,13 @@ static const GtkStockItem items[] = {
   { ST_STOCK_TUNE_IN, N_("_Tune in"), 0, 0, NULL },
   { ST_STOCK_RECORD, N_("_Record"), 0, 0, NULL },
   { ST_STOCK_BROWSE, N_("_Browse"), 0, 0, NULL },
+  { ST_STOCK_RELOAD, N_("_Reload"), 0, 0, NULL },
   { ST_STOCK_QUIT_WITHOUT_SAVING, N_("_Quit Without Saving"), 0, 0, NULL },
   { ST_STOCK_OPEN_LINK, N_("_Open Link"), 0, 0, NULL },
   { ST_STOCK_COPY_LINK_ADDRESS, N_("_Copy Link Address"), 0, 0, NULL },
   { ST_STOCK_NEW_PRESELECTION, N_("_New Preselection"), 0, 0, NULL },
-  { ST_STOCK_ADD_BOOKMARK, N_("_Add Bookmark"), 0, 0, NULL }
+  { ST_STOCK_ADD_BOOKMARK, N_("_Add Bookmark"), 0, 0, NULL },
+  { ST_STOCK_LEAVE_FULLSCREEN, N_("Leave Fullscreen"), 0, 0, NULL },
 };
 
 /*** implementation **********************************************************/
@@ -64,17 +65,20 @@ void
 st_stock_init (void)
 {
   const sGtkStockIcon icons[] = {
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_TUNE_IN, art_tune_in),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_RECORD, art_record),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_BROWSE, art_browse),
-    SGTK_STOCK_ICON_STOCK(ST_STOCK_QUIT_WITHOUT_SAVING, GTK_STOCK_QUIT),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_SEARCH, art_search),
-    SGTK_STOCK_ICON_STOCK(ST_STOCK_OPEN_LINK, GTK_STOCK_OPEN),
-    SGTK_STOCK_ICON_STOCK(ST_STOCK_COPY_LINK_ADDRESS, GTK_STOCK_COPY),
-    SGTK_STOCK_ICON_STOCK(ST_STOCK_NEW_PRESELECTION, GTK_STOCK_NEW),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_ADD_BOOKMARK, art_add_bookmark),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_CATEGORY, art_category),
-    SGTK_STOCK_ICON_INLINE(ST_STOCK_CATEGORY_OPEN, art_category_open),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_TUNE_IN, art_tune_in),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_RECORD, art_record),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_BROWSE, art_browse),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_RELOAD, GTK_STOCK_REFRESH),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_QUIT_WITHOUT_SAVING, GTK_STOCK_QUIT),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_SEARCH, art_search),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_OPEN_LINK, GTK_STOCK_OPEN),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_COPY_LINK_ADDRESS, GTK_STOCK_COPY),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_NEW_PRESELECTION, GTK_STOCK_NEW),
+    SGTK_STOCK_ICON_FROM_THEME(ST_STOCK_ADD_BOOKMARK, "stock_add-bookmark"),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_CATEGORY, art_category),
+    SGTK_STOCK_ICON_FROM_INLINE(ST_STOCK_CATEGORY_OPEN, art_category_open),
+    SGTK_STOCK_ICON_FROM_STOCK(ST_STOCK_LEAVE_FULLSCREEN, GTK_STOCK_QUIT),
+    SGTK_STOCK_ICON_FROM_THEME(ST_STOCK_SELECT_ALL, "stock_select-all"),
     SGTK_STOCK_ICON_END
   };
       
