@@ -1,5 +1,5 @@
 /*
- * $Id: st-stock.h,v 1.24 2004/03/24 16:34:06 jylefort Exp $
+ * $Id: st-stock.h,v 1.24.2.4 2004/08/06 18:53:54 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -38,6 +38,8 @@
 #define ST_STOCK_RECORD			"st-record"
 #define ST_STOCK_BROWSE			"st-browse"
 
+#define ST_STOCK_RELOAD			"st-reload"
+
 #define ST_STOCK_QUIT_WITHOUT_SAVING	"st-quit-without-saving"
 #define ST_STOCK_SEARCH			"st-search"
 #define ST_STOCK_OPEN_LINK		"st-open-link"
@@ -49,6 +51,10 @@
 #define ST_STOCK_CATEGORY		"st-category"
 #define ST_STOCK_CATEGORY_OPEN		"st-category-open"
 
+#define ST_STOCK_LEAVE_FULLSCREEN	"st-leave-fullscreen"
+
+#define ST_STOCK_SELECT_ALL		"st-select-all"
+
 void st_stock_init (void);
 
 #endif /* _ST_STOCK_H */
