@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-bag.c,v 1.50.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-stream-bag.c,v 1.50.2.2 2004/07/24 16:17:26 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -416,3 +416,46 @@ st_stream_bag_delete (STStreamBag *bag, GError **err)
   else
     return FALSE;
 }
+
+gboolean
+st_stream_bag_matches (STStreamBag *bag,
+		       const char *token,
+		       gboolean case_sensitive)
+{
+  GSList *l;
+  gboolean matches = FALSE;
+
+  g_return_val_if_fail(ST_IS_STREAM_BAG(bag), FALSE);
+  g_return_val_if_fail(token != NULL, FALSE);
+
+  SG_LIST_FOREACH(l, st_handler_get_fields(bag->handler))
+    {
+      STHandlerField *field = l->data;
+
+      if (ST_HANDLER_FIELD_IS_VISIBLE(field))
+	{
+	  GValue value = { 0, };
+	  GValue transformed = { 0, };
+
+	  st_stream_bag_get_field(bag, field, &value);
+	  g_value_init(&transformed, G_TYPE_STRING);
+
+	  if (g_value_transform(&value, &transformed))
+	    {
+	      const char *str = g_value_get_string(&transformed);
+	      if (str)
+		matches = case_sensitive
+		  ? sg_utf8_strcontains(str, token)
+		  : sg_utf8_strcasecontains(str, token);
+	    }
+
+	  g_value_unset(&value);
+	  g_value_unset(&transformed);
+
+	  if (matches)
+	    break;
+	}
+    }
+
+  return matches;
+}
