@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-menu-items.c,v 1.23 2004/03/24 16:34:06 jylefort Exp $
+ * $Id: st-stream-menu-items.c,v 1.23.2.2 2004/08/05 15:48:13 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -45,11 +45,9 @@ struct _STStreamMenuItems
   GtkWidget	*record;
   GtkWidget	*browse;
   GtkWidget	*separator1;
-  GtkWidget	*new_preselection;
   GtkWidget	*add_bookmark;
-  GtkWidget	*separator2;
   GtkWidget	*delete;
-  GtkWidget	*separator3;
+  GtkWidget	*separator2;
   GtkWidget	*properties;
 };
 
@@ -67,11 +65,9 @@ st_stream_menu_items_new (STShell *shell, GtkAccelGroup *accel_group)
   items->record = gtk_image_menu_item_new_from_stock(ST_STOCK_RECORD, accel_group);
   items->browse = gtk_image_menu_item_new_from_stock(ST_STOCK_BROWSE, accel_group);
   items->separator1 = gtk_separator_menu_item_new();
-  items->new_preselection = gtk_image_menu_item_new_from_stock(ST_STOCK_NEW_PRESELECTION, accel_group);
   items->add_bookmark = gtk_image_menu_item_new_from_stock(ST_STOCK_ADD_BOOKMARK, accel_group);
-  items->separator2 = gtk_separator_menu_item_new();
   items->delete = gtk_image_menu_item_new_from_stock(GTK_STOCK_DELETE, accel_group);
-  items->separator3 = gtk_separator_menu_item_new();
+  items->separator2 = gtk_separator_menu_item_new();
   items->properties = gtk_image_menu_item_new_from_stock(GTK_STOCK_PROPERTIES, accel_group);
   
   g_signal_connect_swapped(G_OBJECT(items->tune_in),
@@ -86,10 +82,6 @@ st_stream_menu_items_new (STShell *shell, GtkAccelGroup *accel_group)
 			   "activate",
 			   G_CALLBACK(st_shell_browse),
 			   items->shell);
-  g_signal_connect_swapped(G_OBJECT(items->new_preselection),
-			   "activate",
-			   G_CALLBACK(st_shell_new_preselection),
-			   items->shell);
   g_signal_connect_swapped(G_OBJECT(items->add_bookmark),
 			   "activate",
 			   G_CALLBACK(st_shell_add_bookmarks),
@@ -107,11 +99,9 @@ st_stream_menu_items_new (STShell *shell, GtkAccelGroup *accel_group)
   gtk_widget_show(items->record);
   gtk_widget_show(items->browse);
   gtk_widget_show(items->separator1);
-  gtk_widget_show(items->new_preselection);
   gtk_widget_show(items->add_bookmark);
-  gtk_widget_show(items->separator2);
   gtk_widget_show(items->delete);
-  gtk_widget_show(items->separator3);
+  gtk_widget_show(items->separator2);
   gtk_widget_show(items->properties);
 
   return items;
@@ -139,37 +129,19 @@ st_stream_menu_items_update_sensitivity (STStreamMenuItems *items)
 }
 
 void
-st_stream_menu_items_append_to_shell (STStreamMenuItems *items,
-				      GtkMenuShell *menu_shell)
+st_stream_menu_items_insert_into_shell (STStreamMenuItems *items,
+					GtkMenuShell *menu_shell,
+					int position)
 {
   g_return_if_fail(items != NULL);
+  g_return_if_fail(GTK_IS_MENU_SHELL(menu_shell));
   
-  gtk_menu_shell_append(menu_shell, items->tune_in);
-  gtk_menu_shell_append(menu_shell, items->record);
-  gtk_menu_shell_append(menu_shell, items->browse);
-  gtk_menu_shell_append(menu_shell, items->separator1);
-  gtk_menu_shell_append(menu_shell, items->new_preselection);
-  gtk_menu_shell_append(menu_shell, items->add_bookmark);
-  gtk_menu_shell_append(menu_shell, items->separator2);
-  gtk_menu_shell_append(menu_shell, items->delete);
-  gtk_menu_shell_append(menu_shell, items->separator3);
-  gtk_menu_shell_append(menu_shell, items->properties);
-}
-
-void
-st_stream_menu_items_prepend_to_shell (STStreamMenuItems *items,
-				       GtkMenuShell *menu_shell)
-{
-  g_return_if_fail(items != NULL);
-  
-  gtk_menu_shell_prepend(menu_shell, items->properties);
-  gtk_menu_shell_prepend(menu_shell, items->separator3);
-  gtk_menu_shell_prepend(menu_shell, items->delete);
-  gtk_menu_shell_prepend(menu_shell, items->separator2);
-  gtk_menu_shell_prepend(menu_shell, items->add_bookmark);
-  gtk_menu_shell_prepend(menu_shell, items->new_preselection);
-  gtk_menu_shell_prepend(menu_shell, items->separator1);
-  gtk_menu_shell_prepend(menu_shell, items->browse);
-  gtk_menu_shell_prepend(menu_shell, items->record);
-  gtk_menu_shell_prepend(menu_shell, items->tune_in);
+  gtk_menu_shell_insert(menu_shell, items->tune_in, position++);
+  gtk_menu_shell_insert(menu_shell, items->record, position++);
+  gtk_menu_shell_insert(menu_shell, items->browse, position++);
+  gtk_menu_shell_insert(menu_shell, items->separator1, position++);
+  gtk_menu_shell_insert(menu_shell, items->add_bookmark, position++);
+  gtk_menu_shell_insert(menu_shell, items->delete, position++);
+  gtk_menu_shell_insert(menu_shell, items->separator2, position++);
+  gtk_menu_shell_insert(menu_shell, items->properties, position++);
 }
