@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-menu-items.h,v 1.16 2004/03/07 08:22:00 jylefort Exp $
+ * $Id: st-stream-menu-items.h,v 1.16.2.1 2004/08/05 15:48:13 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -45,9 +45,8 @@ void              st_stream_menu_items_free (STStreamMenuItems	*items);
 
 void st_stream_menu_items_update_sensitivity	(STStreamMenuItems  *items);
 
-void st_stream_menu_items_append_to_shell	(STStreamMenuItems  *items,
-						 GtkMenuShell	    *menu_shell);
-void st_stream_menu_items_prepend_to_shell	(STStreamMenuItems  *items,
-						 GtkMenuShell	    *menu_shell);
+void st_stream_menu_items_insert_into_shell	(STStreamMenuItems  *items,
+						 GtkMenuShell       *menu_shell,
+						 int                position);
 
 #endif /* _ST_STREAM_MENU_ITEMS_H */
