@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-properties-dialog.c,v 1.86.2.2 2004/05/11 15:40:42 jylefort Exp $
+ * $Id: st-stream-properties-dialog.c,v 1.86.2.4 2004/08/05 13:48:27 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -295,7 +295,7 @@ st_stream_properties_dialog_construct_table (STStreamPropertiesDialog *dialog)
 	      GtkWidget *hbox;
 	      GSList *m;
 
-	      str = g_strdup_printf("<span weight=\"bold\">%s:</span>", st_handler_field_get_label(field));
+	      str = g_markup_printf_escaped("<span weight=\"bold\">%s:</span>", st_handler_field_get_label(field));
 	      label = gtk_label_new(str);
 	      g_free(str);
 
@@ -760,7 +760,7 @@ st_stream_properties_dialog_apply (STStreamPropertiesDialog *dialog)
       normalized = st_dialog_normalize(err->message);
       g_error_free(err);
 
-      st_error_dialog(_("Unable to apply all modifications."), "%s", normalized);
+      st_error_dialog(_("Unable to apply all modifications"), "%s", normalized);
       g_free(normalized);
     }
 
@@ -798,7 +798,7 @@ st_stream_properties_dialog_cancel (STStreamPropertiesDialog *dialog)
 	  normalized = st_dialog_normalize(err->message);
 	  g_error_free(err);
 
-	  st_error_dialog(_("Unable to cancel all modifications."), "%s", normalized);
+	  st_error_dialog(_("Unable to cancel all modifications"), "%s", normalized);
 	  g_free(normalized);
 	}
     }
