@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-store.c,v 1.30.2.1 2004/07/24 16:17:26 jylefort Exp $
+ * $Id: st-stream-store.c,v 1.30.2.2 2004/08/09 12:35:57 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -31,37 +31,20 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <string.h>
 #include "sg-util.h"
+#include "sgtk-util.h"
 #include "st-stream-store.h"
 #include "st-handler-field.h"
 #include "st-handler.h"
 
-/*** type definitions ********************************************************/
-
-struct _STStreamStorePrivate
-{
-  int count;
-};
-
 /*** variable declarations ***************************************************/
 
-static GObjectClass *parent_class = NULL;
 static GdkPixbuf *blank_pixbuf = NULL;
 
 /*** function declarations ***************************************************/
 
 static void st_stream_store_class_init (STStreamStoreClass *class);
-static void st_stream_store_init (STStreamStore *store);
-static void st_stream_store_finalize (GObject *object);
 
-static void st_stream_store_row_deleted_h (GtkTreeModel *model,
-					   GtkTreePath *arg1,
-					   gpointer user_data);
-static void st_stream_store_row_inserted_h (GtkTreeModel *model,
-					    GtkTreePath *arg1,
-					    GtkTreeIter *arg2,
-					    gpointer user_data);
 static void st_stream_store_sort_column_changed_h (GtkTreeSortable *treesortable,
 						   gpointer user_data);
 
@@ -96,7 +79,7 @@ st_stream_store_get_type (void)
 	NULL,
 	sizeof(STStreamStore),
 	0,
-	(GInstanceInitFunc) st_stream_store_init,
+	NULL
       };
       
       stream_store_type = g_type_register_static(GTK_TYPE_LIST_STORE,
@@ -111,15 +94,10 @@ st_stream_store_get_type (void)
 static void
 st_stream_store_class_init (STStreamStoreClass *class)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS(class);
   gboolean status;
   int width;
   int height;
 
-  parent_class = g_type_class_peek_parent(class);
-
-  object_class->finalize = st_stream_store_finalize;
-
   /* create a blank pixbuf for ST_STREAM_BAG_STATE_NORMAL */
 
   status = gtk_icon_size_lookup(GTK_ICON_SIZE_MENU, &width, &height);
@@ -129,22 +107,6 @@ st_stream_store_class_init (STStreamStoreClass *class)
   gdk_pixbuf_fill(blank_pixbuf, 0); /* fill with transparent black */
 }
 
-static void
-st_stream_store_init (STStreamStore *store)
-{
-  store->priv = g_new0(STStreamStorePrivate, 1);
-}
-
-static void
-st_stream_store_finalize (GObject *object)
-{
-  STStreamStore *store = ST_STREAM_STORE(object);
-
-  g_free(store->priv);
-
-  G_OBJECT_CLASS(parent_class)->finalize(object);
-}
-
 STStreamStore *
 st_stream_store_new (STHandler *handler)
 {
@@ -191,39 +153,16 @@ st_stream_store_new (STHandler *handler)
 
   /* bind signals */
 
-  g_signal_connect(G_OBJECT(store),
-		   "row-deleted",
-		   G_CALLBACK(st_stream_store_row_deleted_h),
-		   NULL);
-  g_signal_connect(G_OBJECT(store),
-		   "row-inserted",
-		   G_CALLBACK(st_stream_store_row_inserted_h),
-		   NULL);
   g_signal_connect(G_OBJECT(store),
 		   "sort-column-changed",
 		   G_CALLBACK(st_stream_store_sort_column_changed_h),
 		   handler);
 
+  sgtk_tree_model_make_countable(GTK_TREE_MODEL(store));
+
   return store;
 }
 
-static void
-st_stream_store_row_deleted_h (GtkTreeModel *model,
-			       GtkTreePath *arg1,
-			       gpointer user_data)
-{
-  ST_STREAM_STORE(model)->priv->count--;
-}
-
-static void
-st_stream_store_row_inserted_h (GtkTreeModel *model,
-				GtkTreePath *arg1,
-				GtkTreeIter *arg2,
-				gpointer user_data)
-{
-  ST_STREAM_STORE(model)->priv->count++;
-}
-
 static void
 st_stream_store_sort_column_changed_h (GtkTreeSortable *treesortable,
 				       gpointer user_data)
@@ -402,14 +341,6 @@ st_stream_store_foreach (STStreamStore *store,
     }
 }
 
-int
-st_stream_store_count (STStreamStore *store)
-{
-  g_return_val_if_fail(ST_IS_STREAM_STORE(store), -1);
-
-  return store->priv->count;
-}
-
 gboolean
 st_stream_store_search_equal_func (GtkTreeModel *model,
 				   int column,
