@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-view.c,v 1.132.2.7 2004/07/24 17:32:42 jylefort Exp $
+ * $Id: st-stream-view.c,v 1.132.2.10 2004/08/09 12:49:56 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -65,10 +65,6 @@ struct _STStreamViewPrivate
 {
   STHandler		*handler;
   STStreamMenuItems	*menu_items;
-  unsigned int		selection_changed_hid;
-
-  gboolean		find_iter_valid;
-  GtkTreeIter		find_iter;
 };
   
 /*** variable declarations ***************************************************/
@@ -236,10 +232,10 @@ st_stream_view_constructor (GType type,
   selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(view));
 
   gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
-  view->priv->selection_changed_hid = g_signal_connect(G_OBJECT(selection),
-						       "changed",
-						       G_CALLBACK(st_stream_view_selection_changed_h),
-						       view);
+  g_signal_connect(G_OBJECT(selection),
+		   "changed",
+		   G_CALLBACK(st_stream_view_selection_changed_h),
+		   view);
 
   st_stream_view_construct_columns(view);
 
@@ -528,21 +524,6 @@ st_stream_view_selection_changed_h (GtkTreeSelection *selection,
 				    gpointer user_data)
 {
   STStreamView *view = user_data;
-  GSList *selected_streams;
-
-  selected_streams = st_stream_view_get_selected_streams(view);
-  if (selected_streams)
-    {
-      GSList *last = g_slist_last(selected_streams);
-      STStreamBag *bag = last->data;
-
-      view->priv->find_iter_valid = TRUE;
-      view->priv->find_iter = bag->iter;
-
-      sg_objects_free(selected_streams);
-    }
-  else
-    view->priv->find_iter_valid = FALSE;
   
   g_signal_emit(view, stream_view_signals[SELECTION_CHANGED], 0);
 }
@@ -740,7 +721,7 @@ st_stream_view_set_menu_items (STStreamView *view, STStreamMenuItems *items)
   view->priv->menu_items = items;
   
   menu = gtk_menu_new();
-  st_stream_menu_items_append_to_shell(view->priv->menu_items, GTK_MENU_SHELL(menu));
+  st_stream_menu_items_insert_into_shell(view->priv->menu_items, GTK_MENU_SHELL(menu), 0);
 
   g_signal_connect_swapped(G_OBJECT(view),
 			   "popup-menu",
@@ -758,7 +739,6 @@ st_stream_view_set_store (STStreamView *view, STStreamStore *store)
   g_return_if_fail(ST_IS_STREAM_VIEW(view));
   
   gtk_tree_view_set_model(GTK_TREE_VIEW(view), GTK_TREE_MODEL(store));
-  view->priv->find_iter_valid = FALSE;
 
   g_signal_emit(view, stream_view_signals[SELECTION_CHANGED], 0);
 }
@@ -848,14 +828,21 @@ st_stream_view_find (STStreamView *view,
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(view));
   if (model)
     {
+      GSList *selected_streams;
       gboolean valid;
       GtkTreeIter iter;
       gboolean edge_hit = FALSE;
 
-      if (view->priv->find_iter_valid)
+      selected_streams = st_stream_view_get_selected_streams(view);
+      if (selected_streams)
 	{
-	  iter = view->priv->find_iter;
+	  GSList *last = g_slist_last(selected_streams);
+	  STStreamBag *bag = last->data;
+
+	  iter = bag->iter;
 	  valid = sgtk_tree_model_iter_move(model, &iter, direction);
+
+	  sg_objects_free(selected_streams);
 	}
       else
 	valid = gtk_tree_model_get_iter_first(model, &iter);
