@@ -1,5 +1,5 @@
 /*
- * $Id: st-stream-view.h,v 1.39 2004/03/27 21:48:10 jylefort Exp $
+ * $Id: st-stream-view.h,v 1.39.2.2 2004/07/24 16:17:26 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -35,6 +35,7 @@
 #define _ST_STREAM_VIEW_H
 
 #include <gtk/gtk.h>
+#include "sgtk-util.h"
 #include "st-handler.h"
 #include "st-stream-menu-items.h"
 
@@ -85,4 +86,12 @@ void		st_stream_view_set_store           (STStreamView  *view,
 GSList		*st_stream_view_get_selected_streams	(STStreamView *view);
 gboolean	st_stream_view_has_selected_streams	(STStreamView *view);
 
+void		st_stream_view_select_all          (STStreamView  *view);
+
+gboolean	st_stream_view_find                (STStreamView  *view,
+						    sGtkDirection direction,
+						    const char    *token,
+						    gboolean      case_sensitive,
+						    gboolean      wrap_around);
+
 #endif /* _ST_STREAM_VIEW_H */
