@@ -1,5 +1,5 @@
 /*
- * $Id: st-transfer.c,v 1.73.2.7 2004/07/26 14:38:27 jylefort Exp $
+ * $Id: st-transfer.c,v 1.73.2.9 2004/08/05 13:19:28 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -118,7 +118,7 @@ static gboolean st_transfer_set_proxy_settings (STTransfer *transfer);
 static void st_transfer_free_proxy_settings (STTransfer *transfer);
 
 #ifndef ST_REGRESSION_TEST
-static char *st_transfer_password_prompt (const char *username);
+static char *st_transfer_password_prompt (void);
 #endif /* ST_REGRESSION_TEST */
 
 static gboolean st_transfer_progress_cb (gpointer data,
@@ -661,7 +661,7 @@ st_transfer_set_proxy_settings (STTransfer *transfer)
 	{
 	  GDK_THREADS_ENTER();
 	  st_thread_printf(transfer->thread, _("Waiting for proxy password..."));
-	  password = st_transfer_password_prompt(st_settings.proxy_auth_name);
+	  password = st_transfer_password_prompt();
 	  gdk_flush();
 	  GDK_THREADS_LEAVE();
 	}
@@ -753,17 +753,17 @@ st_transfer_progress_cb (gpointer data,
 
 #ifndef ST_REGRESSION_TEST
 static char *
-st_transfer_password_prompt (const char *username)
+st_transfer_password_prompt (void)
 {
   GtkWidget *dialog;
   char *password = NULL;
 
-  g_return_val_if_fail(username != NULL, NULL);
-
   dialog = sgtk_auth_dialog_new(st_main_get_transient(),
-				_("Please enter your proxy password."));
+				_("Password required"),
+				_("Enter your password for proxy '%s'."),
+				st_settings.proxy_server);
 
-  sgtk_auth_dialog_set_name(SGTK_AUTH_DIALOG(dialog), username);
+  sgtk_auth_dialog_set_name(SGTK_AUTH_DIALOG(dialog), st_settings.proxy_auth_name);
   sgtk_auth_dialog_set_name_sensitive(SGTK_AUTH_DIALOG(dialog), FALSE);
 
   if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
@@ -874,7 +874,7 @@ st_transfer_init (void)
 #ifdef ST_REGRESSION_TEST
       g_critical("unable to initialize libcurl");
 #else
-      st_error_dialog(_("A fatal error has occurred."),
+      st_error_dialog(_("A fatal error has occurred"),
 		      _("Unable to initialize the curl library."));
       exit(1);
 #endif ST_REGRESSION_TEST
